@@ -1,9 +1,10 @@
 //*****************************************************************************
-// copyright (c) 1998-2002 TLK Games all rights reserved
+// copyright (c) 1998-2005 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
-// file         : "bonus.cpp"
-// created      : ?
-// updates      : 2002-08-11
+// file		: "bonus.cpp"
+// created	: ?
+// updates	: 2005-01-08
+// id		: $Id: bonus.cpp,v 1.1.1.1 2005/01/25 05:52:09 gurumeditation Exp $
 //-----------------------------------------------------------------------------
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -22,6 +23,7 @@
 //*****************************************************************************
 #include "powermanga.hpp"
 //..............................................................................
+extern configfile*      power_conf;
 extern short            nbr_nmis;                              // nombre d'enemis actuellement geres.
 extern int              num_level;                             // level number
 extern bool             player_pause;                          // 1=pause enable
@@ -32,7 +34,6 @@ extern int              tmp_tsts_x;
 extern int              tmp_tsts_y;
 extern int              tmp_tstd_x;
 extern int              tmp_tstd_y;
-extern int              gameLevel;                             // Game difficulty (Laurent Duperval)
 extern bool             option_change;                         // 1=option change (udpate panel)
 extern vaisseau         vj[NBR_MAX_J];                         // stucture's ship of player
 extern char            *ecran_ram;                             // adresse ecran logique.
@@ -46,7 +47,7 @@ extern int              liste_bou[MAX_BOULES_ON_SCREEN];       // definit la lis
 extern str_boule        bou[MAX_BOULES_ON_SCREEN];             // declaration de la structure des boules.
 extern image            boule[MAX_TYP_OF_BOULES][NBR_IMAGES_BOULES];    // Definit le tableau des differents ennemis.
 extern bool             eclair_actif;                          // Indique si le joueur peut ou non utiliser l'eclair.
-extern option           aff_option[11];                        // Tableau utilise pour l'affichage des options pendant le jeu.
+extern option           aff_option[MAX_TYP_OF_OPTIONS];                        // Tableau utilise pour l'affichage des options pendant le jeu.
 extern int              nbr_onde_choc;                         // Defini le nombre actuel d'onde de choc.
 extern int              cmpt_onde_choc;                        // Utilise pour compter les ondes de choc dans les bcles.
 extern onde_de_choc     onde_choc[NBR_ONDE_CHOC_MAX];          // Defini le tableau des differentes ondes de choc.
@@ -163,7 +164,7 @@ void bonus_execution()
                   {                                            // Incremente le nombre de bonus du joueur.
                     vj[J1].nbr_bonus++;
                     option_change = TRUE;                      //indique que l'etat des options a change
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
                     seal_joue(BONUS1);                         //joue son du bonus 1
 #endif
                   }
@@ -173,7 +174,7 @@ void bonus_execution()
                   {                                            // Incremente le nombre de bonus du joueur.
                     vj[J1].nbr_bonus += 2;
                     option_change = TRUE;                      //indique que l'etat des options a change
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
                     seal_joue(BONUS2);                         //son "bonus2 
 #endif
                   }
@@ -182,7 +183,7 @@ void bonus_execution()
                   case 2:
                   {
                     ajoute_boule();
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
                     seal_joue(BONUS3);                         //son du bonus 3.
 #endif
                   }
@@ -193,7 +194,7 @@ void bonus_execution()
                     if(vj[J1].spr.etat_dommages < vj[J1].spr.pow_of_dest)
                     {                                          // On indique que l'option d'energie est ouverte.
                       aff_option[1].close_option = FALSE;
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
                       seal_joue(BONUS4);                       //joue son bonus 4.
 #endif
                     }
@@ -209,7 +210,7 @@ void bonus_execution()
                         (int)(vj[J1].spr.coor_y +
                               vj[J1].spr.img[vj[J1].spr.img_act]->y_cg);
                       // Joue le son de l'onde de chocu tir 1.
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
                       seal_joue(ONDE_CHOC);                    //joue un son avec seal
 #endif
                     }
@@ -293,7 +294,7 @@ void ajoute_boule()
   if(nbr_boules < 5)
   {                                                            // On rajoute une boule dans la liste.
     new_bou = New_Element_Bou();                               // Retourne l'indice dans le tableau 'bou' d'un nouvel element de la liste.
-    bou[new_bou].app_vaisseau = 0;                             // Indique le vaisseau a qui appartient cette boule.
+	//bou[new_bou].app_vaisseau = 0;
     bou[new_bou].nbr_pts_cercle = 80;                          // Indique le nombre de points composant le cercle.
     bou[liste_bou[0]].pos_pts_cercle = 0;                      // Indique la position du pointeur sur le tableau des points du cercle.
     bou[new_bou].etat_dommages = (short)(50 + vj[J1].type_vaisseau * 10);       //si =< 0 cela indique que la boule est detruite, si > 0 cela   indique l'etat des dommages.
@@ -463,7 +464,7 @@ void Gene_Bonus_Malus(float pos_x, float pos_y)
 int Calculate_Bonus(int value)
 {
   int retValue = -1;
-  if (gameLevel == 2)
+  if (power_conf->difficulty == 2)
   {
     if (value < 5)      { retValue = BONUS_INCR_BY_1; }
     else if (value==10) { retValue = BONUS_INCR_BY_2; }
@@ -475,7 +476,7 @@ int Calculate_Bonus(int value)
       }
     }
   }
-  else if (gameLevel == 1)
+  else if (power_conf->difficulty == 1)
   {
     if (value < 10)   { retValue = BONUS_INCR_BY_1; }
     else if (value==10) { retValue = BONUS_INCR_BY_2; }
@@ -487,7 +488,7 @@ int Calculate_Bonus(int value)
       }
     }
   }
-  else if (gameLevel == 0)
+  else if (power_conf->difficulty == 0)
   { if (value < 15)      { retValue = BONUS_INCR_BY_1; }
     else if (value < 22) { retValue = BONUS_INCR_BY_2; }
     else if (value < 25) { retValue = BONUS_PROT_BALL; }
@@ -629,7 +630,7 @@ void Gene_Bonus_Malus_Meteor(float pos_x, float pos_y)
 int Calculate_Bonus_Meteor(int value)
 {
   int retValue = -1;
-  switch (gameLevel)
+  switch (power_conf->difficulty)
   { case 0: 
       if (value < 10)                                                           { retValue = BONUS_INCR_BY_1; }
       if (value==10 || value == 11)                                             { retValue = BONUS_INCR_BY_2; }
@@ -654,7 +655,7 @@ int Calculate_Bonus_Meteor(int value)
       else if (value==6 && (rand()%2))                                          { retValue = BONUS_PROT_BALL; }
       else if (value==7 || value==35 || value==50 && (rand() %2))               { retValue = BONUS_INCR_ENERGY; }
       else if (value==40 && !(rand()%6))                                        { retValue = BONUS_TIMES_2; }
-      else if (!rand()%6)                                                       { retValue = BONUS_SPECIAL_SHIP; }
+      else if (!(rand()%6))                                                       { retValue = BONUS_SPECIAL_SHIP; }
   }
   return retValue;
 }
