@@ -1,15 +1,15 @@
 //*****************************************************************************
-// copyright (c) 1998-2004 TLK Games all rights reserved
+// copyright (c) 1998-2005 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
-// file         : "congratulations.cpp"
-// created      : 1999-03-26
-// updates      : 2004-07-31
+// file		: "congratulations.cpp"
+// created	: 1999-03-26
+// updates	: 2005-01-08
+// id		: $Id: congratulations.cpp,v 1.1.1.1 2005/01/25 05:52:19 gurumeditation Exp $
 //-----------------------------------------------------------------------------
 // fonctions    : void  _init_congra()
-//                void  _execute_congra(int)
+//                void  _execute_congratulations(int)
 //                void  nouveau_ennemi()
 //                void  animation_ennemi() 
-//                void _destroy_congra() 
 //-----------------------------------------------------------------------------
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -24,6 +24,7 @@
 // You should have received a copy of the GNU General Public License along with
 // this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 // Place - Suite 330, Boston, MA  02111-1307, USA.
+//
 //******************************************************************************
 #include "powermanga.hpp"
 //------------------------------------------------------------------------------
@@ -61,12 +62,10 @@ extern unsigned int     iJoueIntro;                            //(ETB) (1=animat
 extern bool             aff_game_over;                         //1=display "GAME OVER"
 
 //------------------------------------------------------------------------------
-_chaine                *pChaineG = 0x0;
 unsigned int            iChoixDeplacemement1;
 unsigned int            iEnnemi;
 unsigned int            iEnnemiType;
 unsigned int            iEnnemiCompteur;
-char                    pNomEnnemi[] ="                                      ";
 unsigned int            pEnnemis[] =
 { BOONIES, MOOARCKS, ACHEES, EVILIANS, RAGOONS,
   FLABBIES, BOWANS, HIJACKERS, DISTASIANS, BRITTERS,
@@ -88,6 +87,7 @@ unsigned int            pEnnemis[] =
   ROTIES, STENCHIES, PERTURBIANS, MADIRIANS, BAINIES,
   SHURIKY, NAGGYS, GOZUKY, SOUKEE, QUIBOULY, TOURNADEE, SAAKAMIN
 };
+char                    pNomEnnemi[] ="                                      ";
 char                   *pEnnemisNoms[] =
 { "BOONIES", "MOOARCKS", "ACHEES", "EVILIANS", "RAGOONS",
   "FLABBIES", "BOWANS", "HIJACKERS", "DISTASIANS", "BRITTERS",
@@ -110,6 +110,7 @@ char                   *pEnnemisNoms[] =
   "ROTIES", "STENCHIES", "PERTURBIANS", "MADIRIANS", "BAINIES",
   "SHURIKY", "NAGGYS", "GOZUKY", "SOUKEE", "QUIBOULY", "TOURNADEE", "SAAKAMIN"
 };
+_chaine                *pChaineG = 0x0;
 
 //------------------------------------------------------------------------------
 void                    _init_congra();
@@ -122,35 +123,34 @@ void                    animation_ennemi();
 //------------------------------------------------------------------------------
 void _init_congra()
 {
-  ve[iNumeroGardien].spr.coor_y =
-    (float)(DEBUT_ECRAN_Y - ve[iNumeroGardien].spr.img[15]->haut);
-  iEnnemiCompteur = 0;
-  iTempo3 = 0;
-  iTempo4 = 0;
-  iAngleG1 = 0;
-  iAngleG1 = 2;
-  iTypedeplacement = 0;
-  iEnnemi = New_Element_Ve();                                  // Retourne l'indice dans le tableau 've' d'un nouvel lment de la liste.
-  iNumeroGardien = new_ve;
-  if(pChaineG == 0)
-  {
-    pChaineG = new _chaine();
-    pChaineG->initialise(pNomEnnemi, strlen(pNomEnnemi), 0, 0, LARG_FONTE_GAME, 0);
-  }
-#ifdef UTILISE_SEAL
-  seal_JoueModule(2);                                          //joue musique des congratulations
+	ve[iNumeroGardien].spr.coor_y =
+		(float)(DEBUT_ECRAN_Y - ve[iNumeroGardien].spr.img[15]->haut);
+	iEnnemiCompteur = 0;
+	iTempo3 = 0;
+	iTempo4 = 0;
+	iAngleG1 = 0;
+	iAngleG1 = 2;
+	iTypedeplacement = 0;
+	iEnnemi = New_Element_Ve();                                  // Retourne l'indice dans le tableau 've' d'un nouvel lment de la liste.
+	iNumeroGardien = new_ve;
+	if(!pChaineG)
+		pChaineG = new _chaine(pNomEnnemi, 0, 0, LARG_FONTE_GAME);
+#ifdef USE_SDLMIXER
+	seal_JoueModule(2);                                          //joue musique des congratulations
 #endif
 }
 
+
 //------------------------------------------------------------------------------
-// release pChaineG object
+// release "pChaineG" object
 //------------------------------------------------------------------------------
 void _destroy_congra() 
 {
-  if(pChaineG)
-    delete pChaineG;
-  pChaineG = (_chaine *)NULL;
-}	
+	if(pChaineG)
+		delete pChaineG;
+	pChaineG = (_chaine *)NULL;
+}
+
 
 //------------------------------------------------------------------------------
 // Execute les congratulations
