@@ -1,9 +1,10 @@
 //*****************************************************************************
-// copyright (c) 1998-2004 TLK Games all rights reserved
+// copyright (c) 1998-2006 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
-// file         : "etbfonte.cpp"
-// created      : ?
-// updates      : 2004-08-01
+// file		: "etbfonte.cpp"
+// created	: ?
+// updates	: 2006-03-27
+// id		: $Id: etbfonte1.cpp,v 1.3 2006/03/27 09:10:18 gurumeditation Exp $
 //-----------------------------------------------------------------------------
 // description  : Implementation de la classe _etfonte1
 //                display simples fontes in 8*8 pixels
@@ -33,6 +34,7 @@
 #include "powermanga.hpp"
 //#define               DEVELOPPEMENT2                           //if define then the keys : ctrl+v, ctrl+p and ctrl+b are enable
 //------------------------------------------------------------------------------
+extern configfile*      power_conf;
 extern unsigned int     iOctetsParPixel;                       //nombre d'octets par pixels (1=256 couleurs / 2=65536 couleurs)
 extern int              tmp_apparition_vj;                     //vaisseau joueur : compteur temps apparition 
 extern bool             disparition_vj;                        //vaisseau joueur : 1=disparition 
@@ -71,14 +73,14 @@ extern int              iNumeroGardien;                        //numero du gardi
 extern unsigned int     iNombreZones;                          //nombre total d'adresse memoire reservee
 extern unsigned int     iOctetsTotal;                          //memoire totale reservee
 extern int              taille_mem_glob;                       //taille memoire maximum utilisee
-extern int              gameLevel;                             // Game difficulty (Laurent Duperval)
 
-#ifdef UTILISE_SEAL2
+#ifdef USE_SDLMIXER2
 extern HAC              pBruitages[];
 extern LPAUDIOWAVE      pSons[];
 extern unsigned int     iFlagBruitages[];
 extern unsigned int     iBruitagesVoix;                        //nombre de voix pour les bruitages
 extern unsigned int     iTailleSons;                           //taille des sons
+
 #ifdef DEVELOPPEMENT2
 int                     iBruitage = 0;                         //numero d'un bruitage a jouer
 #endif
@@ -91,7 +93,7 @@ char _etbfonte1::pTexteAbout[]=
   "*                              *@* "\
   POWERMANGA_VERSION\
   "*@*                LINUX VERSION *@"\
-  "* (c) 1998-2004 TLK-GAMES      *@"\
+  "* (c) 1998-2006 TLK-GAMES      *@"\
   "*                              *@"\
   "* LINUX.TLK.FR                 *@"\
   "*                              *@"\
@@ -197,23 +199,23 @@ char	_etbfonte1::pTexteParametres[]=
 // constructeur ****************************************************************
 _etbfonte1::_etbfonte1()
 {
-  iAction = 0;
-  iTempo = 0;
-  iIndexTouch = -1;
-  iParamPosY = 0;
-  iTempoClavier = 0;
-  num_level_sauve = 0;
-  allez_gardien = 14;
-  pFonte = (unsigned char *)NULL;
+	iAction = 0;
+	iTempo = 0;
+	iIndexTouch = -1;
+	iParamPosY = 0;
+	iTempoClavier = 0;
+	num_level_sauve = 0;
+	allez_gardien = 14;
+	pFonte = NULL;
 }
 
 // destructeur *****************************************************************
 _etbfonte1::~_etbfonte1()
 {
-  if(pFonte != 0)
-  { libereMemoire((char *)pFonte);
-    pFonte = 0;
-  }
+	if(pFonte)
+	{	libereMemoire((char *)pFonte);
+		pFonte = NULL;
+	}
 }
 
 //******************************************************************************
@@ -477,7 +479,7 @@ void _etbfonte1::afficheVariables2()
 {
   char                   *_pTexte = pTexteVariables2;
 
-#ifdef UTILISE_SEAL2
+#ifdef USE_SDLMIXER2
   unsigned int i;
   char                   *_p = _pTexte + (33 * 2) + 2;
   int iEtatVoix = 0;
@@ -498,7 +500,7 @@ void _etbfonte1::afficheVariables2()
     _p += 1;
   }
   entier2ASCII(iTailleSons, _pTexte + (33 * 6) + 14, 7);
-  entier2ASCII(gameLevel, _pTexte + (33 * 7) + 12, 0);
+  entier2ASCII(power_conf->difficulty, _pTexte + (33 * 7) + 12, 0);
   //joue un bruitage par touche
   int _iCanal = -1;
   int _iOffset = 0;
