@@ -1,9 +1,10 @@
 //*****************************************************************************
-// copyright (c) 1998-2003 TLK Games all rights reserved
+// copyright (c) 1998-2005 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
-// file         : "explosionExecution.cpp"
-// created      : ?
-// updates      : 2003-07-20
+// file		: "explosionExecution.cpp"
+// created	: ?
+// updates	: 2005-01-09
+// id		: $Id: explosionExecution.cpp,v 1.1.1.1 2005/01/25 05:52:46 gurumeditation Exp $
 //-----------------------------------------------------------------------------
 // functions : void   explosionExecution()
 //             void   Add_Explosion(float c_x, float c_y, float vitesse, int type, int nbr_vbl )
@@ -128,7 +129,7 @@ void Add_Explosion(float c_x, float c_y, float vitesse, int type, int nbr_vbl)
         xpl[new_xpl].vitesse = vitesse;                        //vitesse de deplacement
         xpl[new_xpl].img_angle = 8;
         xpl[new_xpl].nbr_vbl_av_exp = nbr_vbl;                 //duree d'affichage de l'explosion
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
         seal_joue(XPLOB1 + (iCompteurGlobal & 3));             //joue un son avec seal
 #endif
       }
@@ -151,7 +152,7 @@ void Add_Explosion(float c_x, float c_y, float vitesse, int type, int nbr_vbl)
         xpl[new_xpl].vitesse = vitesse;                        //vitesse de deplacement
         xpl[new_xpl].img_angle = 8;
         xpl[new_xpl].nbr_vbl_av_exp = nbr_vbl;                 //duree d'affichage de l'explosion
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
         seal_joue(XPLOC1 + (iCompteurGlobal & 3));             //joue explosion un son avec seal
 #endif
       }
@@ -171,7 +172,7 @@ void Add_Explosion(float c_x, float c_y, float vitesse, int type, int nbr_vbl)
         xpl[new_xpl].vitesse = vitesse; //vitesse deplacement
         xpl[new_xpl].img_angle = 8;
         xpl[new_xpl].nbr_vbl_av_exp = nbr_vbl; //duree d'affichage explosion
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
         seal_joue(XPLOA1 + (iCompteurGlobal & 3));  //son explosion
 #endif
       }
@@ -216,7 +217,7 @@ void Add_Explosion_Guard(float c_x, float c_y)
     xpl[new_xpl].vitesse = -.5;     //vitesse deplacement
     xpl[new_xpl].img_angle = 8;
     xpl[new_xpl].nbr_vbl_av_exp = 0; //duree d'affichage explosion
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
     if(!(rand() % 8))
     { seal_joue(XPLOA1 + (iCompteurGlobal & 3));  //son explosion
     }
