@@ -1,9 +1,9 @@
 //******************************************************************************
-// copyright (c) 1998-2002 TLK Games all rights reserved
+// copyright (c) 1998-2005 TLK Games all rights reserved
 //------------------------------------------------------------------------------
 // file         : "fntscrol.cpp" 
 // created      : ?
-// updates      : 2002-08-18
+// updates      : 2005-01-07
 //------------------------------------------------------------------------------
 // functions    : Init_Scroll_Present()
 //              : Destruct_Scroll_Font(int)
@@ -27,10 +27,10 @@
 // You should have received a copy of the GNU General Public License along with
 // this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 // Place - Suite 330, Boston, MA  02111-1307, USA.
-//
 //******************************************************************************
 #include "powermanga.hpp"
 //..............................................................................
+extern configfile*	power_conf;
 extern fonte            fnt_scroll[NBR_FONTES_SCROLL];         //Tableau de variables utilise pour l'affichage des caracteres qui scrollent.
 extern int              liste_fnt_scroll[NBR_FNT_SCROLL_MAX];  // Dfinit la liste de toutes les fontes qui scrollent que l'on doit grs  chaque VBLs.
 extern int              cmpt_fnt_scroll;                       // Utilis dans les bcles pour compter le nombre de fontes qui scrollent.
@@ -53,16 +53,49 @@ float                   vit_scroll_txt;
 bool                    dir_font_x;
 bool                    dir_font_y;                            // Indique le sens des deplacements.
 char                   *s_empty ="                                                                   ";
-char                   *s_present =
-"WELCOME TO THE MENU OF POWERMANGA. USE THE UP AND DOWN ARROWS TO SELECT A \
-MENU OPTION AND PRESS ENTER TO VALIDATE. DURING THE GAME, USE THE ARROWS TO MOVE THE \
-SHIP, SPACE FOR SHOOTING AND CONTROL TO SELECT AN OPTION, THE P KEY TO PAUSE THE GAME \
-AND THE ESCAPE KEY TO RETURN TO THIS MENU. \
-THE GREEN GEMS INCREASE THE OPTION BY ONE, THE RED GEMS INCREASE THE OPTION BY TWO. \
-THE YELLOW GEMS INCREASE THE NUMBER OF PROTECTION BALLS. \
-WHEN YOU TAKE 6 YELLOW GEMS WITHOUT LOSING A PROTECTION BALL, YOU'LL HAVE A SPECIAL WEAPON. \
-THE PINK GEMS INCREASE YOUR ENERGY AND IF YOUR ENERGY WAS ALREADY FULL IT WILL GIVE YOU A \
-MEGA-BLAST WHICH DESTROYS ALL ENEMIES. POWERMANGA (C) 2002 TLK GAMES.             ";
+
+// scroll text (now loaded from a file in Load_Scroll_Text())
+char*	s_present = NULL;
+
+
+//------------------------------------------------------------------------------
+// load scroll-text
+//------------------------------------------------------------------------------	
+int Load_Scroll_Text()
+{
+	char* pLang = power_conf->get_txtlang();
+	char fname[256];
+	sprintf(fname, "texts/scroll_%s.txt", pLang);
+	Uint32 bsize;
+	char *pTemp = chargeFichier(fname, &bsize);
+	if (!pTemp) return 0;
+	
+	s_present = reserveMemoire(bsize);
+	if (!s_present)
+	{	libereMemoire(pTemp);
+		return 0;
+	}
+	
+	Uint32 j = 0;
+	for(Uint32 i = 0; i < bsize; i++)
+	{	if(pTemp[i] >= ' ' && pTemp[i] != '"')
+			s_present[j++] = pTemp[i];
+	}
+	libereMemoire(pTemp);
+	return 1;
+}
+
+//------------------------------------------------------------------------------
+// Free scroll-text
+//------------------------------------------------------------------------------	
+void Free_Scroll_Text()
+{
+	if (s_present) 
+	{	libereMemoire (s_present);
+		s_present = NULL;
+	}
+}
+
 	
 //------------------------------------------------------------------------------
 // initialize scroll-text
