@@ -1,9 +1,10 @@
 //*****************************************************************************
-// copyright (c) 1998-2002 TLK Games all rights reserved
+// copyright (c) 1998-2005 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "gardien12.cpp"
 // created      : 1999-03-23
-// updates      : 2002-08-02
+// updates      : 2005-01-08
+// id		: $Id: gardien12.cpp,v 1.1.1.1 2005/01/25 05:52:49 gurumeditation Exp $
 //-----------------------------------------------------------------------------
 // infos        : Guardian number 12 : 2*32 images
 //                1 to 8  flip
@@ -236,7 +237,7 @@ void _execute_gardien12(int num_gardien)
           if(nbr_tirs < (NBR_TIRS_MAX - 1))
           {                                                    // Recherche d'un nouveau tir.
             new_tir = New_Element_Tir();
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
             seal_joue(TIR3NMI);                                //joue un son avec seal
 #endif
             // Remplissage de la structure sprite pour le tir du vaisseau ennemi.
@@ -251,8 +252,8 @@ void _execute_gardien12(int num_gardien)
               tirs[new_tir].spr.img[j] = (image *) & fire[TIR1P3E][j];  // Corespond au Tir 2 puissance 2.
             }
             tirs[new_tir].spr.etat_dommages = tirs[new_tir].spr.pow_of_dest;    // Indique l'tat de domages du sprite.
-            tirs[new_tir].spr.pilote = 0;                      // Indique par qui est dirig le sprite.
-            tirs[new_tir].spr.mode_commande = 0;               // Indique le moyen par lequel on fait dplacer le sprite.
+            //tirs[new_tir].spr.pilote = 0;                      // Indique par qui est dirig le sprite.
+            //tirs[new_tir].spr.mode_commande = 0;               // Indique le moyen par lequel on fait dplacer le sprite.
             tirs[new_tir].spr.img_act = 0;                     // Indique l'image actuelle.
             tirs[new_tir].spr.nbr_tot_vbl = 1;                 // Indique le nombre de VBL qu'il faut pour passer  l'image suivante.
             tirs[new_tir].spr.nbr_vbl_act = 0;                 // Indique le nombre de VBL comptes actuellement.
@@ -342,7 +343,7 @@ void ajoute_shuriy(int num_gardien)
   {
     compteur_shuriy = 1;
     iAngleShury = 0;
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
     seal_joue(TIR1);                                           //joue un son avec seal
 #endif
     for(i = 0; i < 5; i++)
