@@ -1,9 +1,10 @@
 //*****************************************************************************
-// copyright (c) 1998-2002 TLK Games all rights reserved
+// copyright (c) 1998-2005 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "gardien14.cpp"
 // created      : 1999-03-26
-// updates      : 2002-08-02
+// updates      : 2005-01-08
+// id		: $Id: gardien14.cpp,v 1.1.1.1 2005/01/25 05:52:54 gurumeditation Exp $
 //-----------------------------------------------------------------------------
 // functions    : void _init_gardien14()
 //                void _execute_gardien14()
@@ -170,7 +171,7 @@ void _execute_gardien14(int num_gardien)
           if(nbr_tirs < (NBR_TIRS_MAX - 1))
           {                                                    // Recherche d'un nouveau tir.
             new_tir = New_Element_Tir();
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
             seal_joue(TIR3NMI);                                //joue un son avec seal
 #endif
             // Remplissage de la structure sprite pour le tir du vaisseau ennemi.
@@ -186,8 +187,8 @@ void _execute_gardien14(int num_gardien)
               tirs[new_tir].spr.img[j] = (image *) & fire[TIR1P3E][j];  // Corespond au Tir 2 puissance 2.
             }
             tirs[new_tir].spr.etat_dommages = tirs[new_tir].spr.pow_of_dest;    // Indique l'tat de domages du sprite.
-            tirs[new_tir].spr.pilote = 0;                      // Indique par qui est dirig le sprite.
-            tirs[new_tir].spr.mode_commande = 0;               // Indique le moyen par lequel on fait dplacer le sprite.
+            //tirs[new_tir].spr.pilote = 0;                      // Indique par qui est dirig le sprite.
+            //tirs[new_tir].spr.mode_commande = 0;               // Indique le moyen par lequel on fait dplacer le sprite.
             tirs[new_tir].spr.img_act = 0;                     // Indique l'image actuelle.
             tirs[new_tir].spr.nbr_tot_vbl = 1;                 // Indique le nombre de VBL qu'il faut pour passer  l'image suivante.
             tirs[new_tir].spr.nbr_vbl_act = 0;                 // Indique le nombre de VBL comptes actuellement.
@@ -303,7 +304,7 @@ void ajoute_saakey(int num_gardien)
   {
     int                     _iNumero;
 
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
     seal_joue(TIR1);                                           //joue un son avec seal
 #endif
     for(int _iCompteur = 0; _iCompteur < iNGHOTTEN; _iCompteur++)
