@@ -1,9 +1,9 @@
 //******************************************************************************
-// copyright (c) 1998-2002 TLK Games all rights reserved
+// copyright (c) 1998-2003 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "gfxbase.cpp"
 // created      : 1999-08-30
-// updates      : 2002-08-02
+// updates      : 2003-07-20
 //-----------------------------------------------------------------------------
 // description  : paserelle sur les routines en langage machine
 //                gatway to the assembler code
@@ -22,8 +22,6 @@
 // this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 // Place - Suite 330, Boston, MA  02111-1307, USA.
 //******************************************************************************
-#include <X11/Xlib.h>
-#include <X11/Xutil.h>
 #include "powermanga.hpp"
 extern char            *pEnnemisNoms[];
 extern image            enemi[MAXTYPENMI][NBR_IMAGES_MAX];     //tableau des images des vaisseaux ennemis
@@ -45,18 +43,18 @@ unsigned int            iOne = 0;
 
 //..............................................................................
 
-void type_routine_gfx ()
+void type_routine_gfx()
 { int flagcode = 0;
   _type_routine_gfx (&flagcode);
   switch(flagcode)
   { case 10:
-      printf("Optimized by assembler routines\n");
+      printf("> gfxbase.cpp/type_routine_gfx(): optimized by assembler routines\n");
       break;
     case 20:
-      printf("Optimized by C routines\n");
+      printf("> gfxbase.cpp/type_routine_gfx(): optimized by C routines\n");
       break;
     default:
-      printf("type_routine_gfx() error\n");
+      printf("> gfxbase.cpp/type_routine_gfx(): type_routine_gfx() error\n");
       break;
   }
 }
@@ -380,20 +378,20 @@ void Aff_Ve(int nmi_numero)
 // -----------------------------------------------------------------------------
 void Aff_Ve2(int nmi_numero)
 {
-  sprite                  ve_spr = ve[nmi_numero].spr;
+  sprite ve_spr = ve[nmi_numero].spr;
 
-  if(ve[nmi_numero].affich_white)                              //affichage en blanc, display mask ?
-  {
-    putsprcolor(coulor[BLANC],
+  //affichage en blanc, display mask ?
+  if(ve[nmi_numero].affich_white)
+  { putsprcolor(coulor[BLANC],
                 ve[nmi_numero].spr.img[ve[nmi_numero].spr.img_act],
                 (int)(ve[nmi_numero].spr.coor_x),
                 (int)(ve[nmi_numero].spr.coor_y));
     ve[nmi_numero].affich_white = 0;
   }
   else
-  {
-    putsprite3(ve[nmi_numero].spr.img[ve[nmi_numero].spr.img_act],
-               (unsigned int)ve[nmi_numero].spr.coor_x, (unsigned int)ve[nmi_numero].spr.coor_y);
+  { putsprite3(ve[nmi_numero].spr.img[ve[nmi_numero].spr.img_act],
+               (unsigned int)ve[nmi_numero].spr.coor_x, 
+               (unsigned int)ve[nmi_numero].spr.coor_y);
     if(nbr_exps < MAX_NMI_ON_SCREEN - 1 && rand() % 2
        && rand() % (ve_spr.etat_max + 1) >
        ve_spr.etat_dommages + (ve_spr.etat_max >> 3))
@@ -403,7 +401,8 @@ void Aff_Ve2(int nmi_numero)
                             rand() % ((int)ve_spr.img[ve_spr.img_act]->lh_zon_col[zon_col][X] +1));
       const float y_expl  = (float)(ve_spr.coor_y + ve_spr.img[ve_spr.img_act]->xy_zon_col[zon_col][Y] +
                             rand() % ((int)ve_spr.img[ve_spr.img_act]->lh_zon_col[zon_col][Y] + 1));
-      Add_Explosion(x_expl, y_expl, -.5, NORM_EXPLOSION, 0);
+      Add_Explosion_Guard(x_expl, y_expl);
+      //Add_Explosion(x_expl, y_expl, -.5, NORM_EXPLOSION, 0);
     }
   }
 }
