@@ -1,9 +1,9 @@
 //*****************************************************************************
-// copyright (c) 2003-2004 Samuel Hocevar <sam@zoy.org>
+// copyright (c) 2003 Samuel Hocevar <sam@zoy.org>
 //-----------------------------------------------------------------------------
 // file         : "gfxroutines.cpp"
 // created      : 2003-04-15
-// updates      : 2004-08-01
+// updates      : 2006-03-26
 //-----------------------------------------------------------------------------
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -98,15 +98,17 @@ void raz_ecran(char *_pEcran, unsigned int _iLargeur,
 void convertitPalette24_16(unsigned char *pal, unsigned short *pal16)
 {
     int i = 256;
-
     while(i--)
     {
         unsigned short dest = 0;
-
-        dest |= (unsigned short)((*pal++) >> 3) << 11;
-        dest |= (unsigned short)((*pal++) >> 3) << 5;
-        dest |= (unsigned short)((*pal++) >> 3) << 0;
-
+	// fix bug, green value range 0 to 64 in 16 bits depth
+	// 2006-03-26
+	dest |= (unsigned short)((*pal++) & 0x000000f8) << 8;
+        dest |= (unsigned short)((*pal++) & 0xfffffffc) << 3;
+        dest |= (unsigned short)((*pal++) & 0x000000f8) >> 3;
+	// dest |= (unsigned short)((*pal++) >> 3) << 11;
+        // dest |= (unsigned short)((*pal++) >> 3) << 5;
+        // dest |= (unsigned short)((*pal++) >> 3) << 0;
         *pal16++ = dest;
     }
 }
@@ -132,10 +134,10 @@ void convertitPalette24_15(unsigned char *pal, unsigned short *pal16)
 #define COPY2X(TYPE) \
     TYPE *src = (TYPE *)_src; \
     TYPE *dest = (TYPE *)_dest; \
-    int i; \
     \
     while(_iHaut--) \
     { \
+        int i; \
         for(i = _iLarge / 8; i--;) \
         { \
             dest[0] = dest[1] = *src++; dest += 2; \
