@@ -1,9 +1,9 @@
 //*****************************************************************************
-// copyright (c) 1998-2004 TLK Games all rights reserved
+// copyright (c) 1998-2003 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "grille.cpp"
 // created      : ?
-// updates      : 2004-08-01
+// updates      : 2003-06-28
 //-----------------------------------------------------------------------------
 // functions    : void  grille_execution()
 //                void  grille_testFin() 
@@ -23,6 +23,7 @@
 // You should have received a copy of the GNU General Public License along with
 // this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 // Place - Suite 330, Boston, MA  02111-1307, USA.
+//
 //*****************************************************************************
 #include "powermanga.hpp"
 //..............................................................................
@@ -114,20 +115,16 @@ int LoadGrid(int num_grid)
   //_p8 = (unsigned char *)_pFichier;
 
   // * windows : il ne faut pas les convertir...
-#ifndef WIN32
-#if __BYTE_ORDER == __BIG_ENDIAN
+/*#if __BYTE_ORDER == __BIG_ENDIAN
   convert32bits_2bigendian ((unsigned char *)_f32);
-#endif
-#endif
+#endif*/
 
   grille.vit_dep_x = (float)*(_f32++);                         //lit un type 'float' (32 bits sur 80x86)
 
-  // * windows : il ne faut pas les convertir...  
-#ifndef WIN32
-#if __BYTE_ORDER == __BIG_ENDIAN
+  // * windows : il ne faut pas les convertir...
+/*#if __BYTE_ORDER == __BIG_ENDIAN
   convert32bits_2bigendian ((unsigned char *)_f32);
-#endif
-#endif
+#endif*/
 
   grille.vit_dep_y = (float)*(_f32++);
   
