@@ -33,7 +33,7 @@ extern image            gardi[NBR_ANIM_GARDIAN][NBR_IMAGES_NMI_S];      //images
 extern fntscroll        fnt_scr[NBR_FNT_SCROLL_MAX];           //tableau de tous les objets caracteres qui defilent
 extern int              liste_fnt_scroll[NBR_FNT_SCROLL_MAX];  //liste des fontes qui defilent actuellement
 extern short            nbr_fnt_scroll;                        //nombre de fontes qui scrollent actuellement grs.
-extern option           aff_option[11];                        // Tableau utilis pour l'affichage des options pendant le jeu.
+extern option           aff_option[MAX_TYP_OF_OPTIONS];                        // Tableau utilis pour l'affichage des options pendant le jeu.
 extern int              num_let_game_over;                     // Utilis pour savoir quelle lettre du game over il faut faire tourner.
 extern int              cmpt_vbl_let_game_over;                // Utilis pour compter le temps qu'il faut avant de faire tourner une lettre du game over.
 extern int              nbr_vbl_game_over;                     // Utilis pour compter le temps qu'il faut avant de faire tourner une lettre du game over.
@@ -862,7 +862,7 @@ char *lecture_compress(unsigned int _iNbr_data_comp, char *_pFichier, char *_pCo
     case 1:                                                   //mode ecran 256 couleurs (on touche rien on laisse comme c'est)
       while (i < _iNbr_data_comp)
       {
-        _iOffset = (unsigned int)litMot16bits(_p16++);         //lecture de l'offset (pour un ecran de 512 pixels de large)
+        _iOffset = (unsigned short)litMot16bits(_p16++);         //lecture de l'offset (pour un ecran de 512 pixels de large)
         i += 2;                                                //on a lu deux octets
         *(_pMem32++) = _iOffset;                               //offset pour un ecran de 512 pixels en "iOctetsParPixel" octets par pixel
         _p8 = (char *)_p16;                                    //acces 8 bits sur le fichier                                                                                                                                   
@@ -939,7 +939,15 @@ char *lecture_compress(unsigned int _iNbr_data_comp, char *_pFichier, char *_pCo
     {
       while (i < _iNbr_data_comp)
       {
-        _iOffset = (unsigned int)litMot16bits(_p16++);         //lecture de l'offset (pour un ecran de 512 pixels de large)
+
+		// remarque : il faut caster litMot16bits() en unsigned short
+		// sinon il arrive que la fonction signed soit appelle,
+		// ca renvoit une valeur negative cast en unsigned,
+		// et fait planter la fonction d'affichage du sprite.
+		// (exemple dans le fichier gardi_8.spr)
+		//
+        _iOffset = (unsigned short)litMot16bits(_p16++);         //lecture de l'offset (pour un ecran de 512 pixels de large)
+
         i += 2;                                                //on a lu deux octets
         _iOffset = _iOffset * 4;                               //quadruple offset (taille ligne trois fois plus grande)
         *(_pMem32++) = _iOffset;                               //offset pour un ecran de 512 pixels en 24 bits
