@@ -1,9 +1,9 @@
 //*****************************************************************************
-// copyright (c) 1998-2004 TLK Games all rights reserved
+// copyright (c) 1998-2002 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
-// file         : "keymap.cpp"
+// file         : "keymap.hpp"
 // created      : ?
-// updates      : 2004-08-01
+// updates      : 2002-08-11
 //------------------------------------------------------------------------------
 // functions    : - void Keys_Down(unsigned int wParam)
 //                - void Keys_Up(unsigend int wParam)
@@ -109,13 +109,6 @@ void keytouch(unsigned int _iCodeTouche, unsigned int i)
     case 'P'          : touch[47]  = i; break;                 //P P=PAUSE
     case 'Q'          : touch[58]  = i; break;                 //Q CTRL+Q gameover
     case 'S'          : touch[60]  = i; break;                 //S CTRL+S coupe la musique
-
-    case XK_KP_6      : touch[73]  = i; break;                 //right arrow 
-    case XK_KP_4      : touch[71]  = i; break;                 //left arrow
-    case XK_KP_8      : touch[55]  = i; break;                 //up arrow
-    case XK_KP_5      : touch[87]  = i; break;                 //down arrow
-    case XK_KP_2      : touch[88]  = i; break;                 //power-up (aka Ctrl key) 
-    case XK_KP_0      : touch[90]  = i; break;                 //fire (aka space bar)
   }
 }
 #endif
