@@ -1,9 +1,9 @@
 //*****************************************************************************
-// copyright (c) 1998-2004 TLK Games all rights reserved
+// copyright (c) 1998-2003 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "linux..hpp"
 // created      : 1999-08-17
-// updates      : 2004-08-04
+// updates      : 2003-06-28
 //-----------------------------------------------------------------------------
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -53,11 +53,6 @@
 
 #endif //WIN32
 
-
-#ifndef _S_ISDIR
-#define _S_ISDIR(__mode) (__mode & _S_IFDIR)
-#endif
-
 //..............................................................................
 #define _VERBEUX_
 #define TRUE                   1
