@@ -1,9 +1,10 @@
 //*****************************************************************************
-// copyright (c) 1998-2003 TLK Games all rights reserved
+// copyright (c) 1998-2006 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
-// file         : "linuxroutines.cpp"
-// created      : 1999-08-19
-// updates      : 2004-08-01 
+// file		: "linuxroutines.cpp"
+// created	: 1999-08-19
+// updates	: 2006-03-26
+// id		: $Id: linuxroutines.cpp,v 1.2 2006/03/26 15:26:20 gurumeditation Exp $
 //------------------------------------------------------------------------------
 // functions    :  int              mem_initialise(unsigned int _iNombreZones)
 //                 char*            reserveMemoire(unsigned int _iTailleMemoire)
@@ -40,17 +41,14 @@
 // Place - Suite 330, Boston, MA  02111-1307, USA.
 //
 //*****************************************************************************
-
 #include "powermanga.hpp"
 #include <errno.h>
-
 #ifndef SDL_TLK
 #include <sys/types.h>
 #include <sys/stat.h>
 #endif
 
 //..............................................................................
-extern unsigned int     iVerbeux;                              //1=affiche les arguments / 1=verbose mode
 
 //gestion de la memoire .........................................................
 typedef struct
@@ -88,6 +86,7 @@ short                   litMot16bitsBig(short *_pMem);
 unsigned short          litMot16bits(unsigned short *_pMem);
 extern const char       nomprefix[];
 extern unsigned int     iFrame3; 
+extern configfile*	power_conf;
 //------------------------------------------------------------------------------
 // initialise la liste memoire / initialise memory table
 // input =>  _iNombreZones : nombre de zones memoire possibles au maximum / number maximum of memory zone
@@ -135,9 +134,10 @@ char *reserveMemoire(unsigned int _iTailleMemoire)
   }
   _pMem = (char *)malloc(_iTailleMemoire);
   if(!_pMem)
-  { printf ("linuxroutines.cpp/reserveMemoire(unsigned int) : malloc(int) return 0 ; size request %i bytes ; total allocate : % i in %i zones\n", _iTailleMemoire, iOctetsTotal, iNombreZones);
+  { printf ("linuxroutines.cpp/reserveMemoire(unsigned int) : calloc(int) return 0 ; size request %i bytes ; total allocate : % i in %i zones\n", _iTailleMemoire, iOctetsTotal, iNombreZones);
     return 0;
   }
+  memset(_pMem, 0, sizeof(char));
   iOctetsTotal += _iTailleMemoire;
   pZoneListeLibre->pMemoire = _pMem;                           //pointeur memoire      
   pZoneListeLibre->iTailleMemoire = _iTailleMemoire;           //taille en octets      
@@ -183,7 +183,12 @@ void libereMemoire(char *_pMemoire)
       }
     }
     if(_pMemoire > 0)
-    { fprintf(stderr, "libereMemoire() : can't release the address %x\n", (int)_pMemoire);
+    {
+#ifdef __LP64__
+	    fprintf(stderr, "libereMemoire() : can't release the address %x\n", (long int)_pMemoire);
+#else
+	    fprintf(stderr, "libereMemoire() : can't release the address %x\n", (int)_pMemoire);
+#endif
     }
   }
   else
@@ -217,13 +222,13 @@ void mem_libereTous()
   char *_pMemoire;
   sListeMemoire *_pListeMem = pZoneListeBase;
 #ifdef _VERBEUX_
-  if(iVerbeux > 0)
+  if(power_conf->verbose)
     fprintf(stdout, "> linuxroutines.cpp/mem_libereTous(): maximum of memory which were allocated during the game : %i\n", iNombreZonesMax);
 #endif
   if(iNombreZones >0)
   { 
 #ifdef _VERBEUX_
-    if(iVerbeux > 0)
+    if(power_conf->verbose)
       fprintf(stdout, "> linuxroutines.cpp/mem_libereTous() : %i zones were not released.\n", iNombreZones);
 #endif
     for(_iCompteur = 0; _iCompteur < iNombreZones; _iCompteur++, _pListeMem++)
@@ -304,7 +309,7 @@ sDescriptionGfx *load_pcx(char *_pNomFichier)
   }
   libereMemoire((char *)_pFichier);
 #ifdef _VERBEUX_
-  if(iVerbeux > 0)
+  if(power_conf->verbose)
     fprintf (
       stdout,
       "> linuxroutines.cpp/load_pcx(): \"%s\"; height=%i; width=%i; size=%i\n",
@@ -350,10 +355,12 @@ short litMot16bits(short *_pMem)
 unsigned short litMot16bits(unsigned short *_pMem)
 {
   unsigned short          _iValeur = 0;
-  unsigned char          *_pMemoire = (unsigned char *)_pMem;
-  _iValeur = _pMemoire[1];                                     //lit du little endian pour un powerpc
+  unsigned char          *_pMemoire = (unsigned char *)_pMem;    
+  
+  _iValeur = _pMemoire[1];                                     //lit du little endian pour un powerpc  
   _iValeur <<= 8;
   _iValeur += _pMemoire[0];
+
   return (_iValeur);
 }
 
@@ -447,18 +454,14 @@ static char pathstring[256];
 
 char *locate_data_file(const char *const name)
 {
-  
-  for(int i = 0; i < 256; i++)
-	pathstring[i] = 0;
-	
   if(name == 0) return 0;
   if(*name == '/') return strdup(name);                        // Guillaume Cottenceau (2001-03-15) replace "return 0;" by "strdup(name);"
                                                                // En effet, nous sommes dans le cas ou le programme recherche dans /usr/share/games/powermanga
   for(const char **p = data_directories;; p++)
-  { char *pathname;
+  { char                   *pathname;
     if(*p == 0)
-    { const char *subdir = "/share/games/powermanga/";
-      pathname = &pathstring[0];
+    { const char             *subdir = "/share/games/powermanga/";
+	  pathname = &pathstring[0];
       /*pathname=(char *)malloc(strlen(nomprefix) + strlen(subdir) + strlen(name) + 1);
       if(pathname == 0)
       { fflush(stdout);
@@ -474,8 +477,7 @@ char *locate_data_file(const char *const name)
       static const char      *home_dir = &bogus;
       if(home_dir == &bogus) home_dir = getenv("HOME");
       if(home_dir == 0) continue;                             // $HOME not set. Skip this directory.
-      pathname = &pathstring[0];
-      
+	  pathname = &pathstring[0];
       /*pathname = (char *)malloc(strlen(home_dir) + 1 + strlen(*p + 1) + 1 + strlen(name) + 1);
       if(pathname == 0)
       { fflush(stdout);
@@ -489,7 +491,7 @@ char *locate_data_file(const char *const name)
     }
     else
     {
-      pathname = &pathstring[0];
+	  pathname = &pathstring[0];
       /*pathname = (char *)malloc(strlen(*p) + 1 + strlen(name) + 1);
       if(pathname == 0)
       { fflush(stdout);
@@ -501,16 +503,24 @@ char *locate_data_file(const char *const name)
       strcat(pathname, name);
     }
     //puts(pathname);  // DEBUG
+/*    struct _stat             s;
+
+	if (_stat(pathname, &s) == 0 && !(s.st_mode & _S_IFDIR)) {		
+		return pathname;
+	}*/
+
 #ifdef WIN32
-    struct _stat s;
-    if(_stat(pathname, &s) == 0 && !_S_ISDIR(s.st_mode))
-      return pathname;
+    struct _stat s;    
+	if (_stat(pathname, &s) == 0 && !(s.st_mode & _S_IFDIR)) 
+		return pathname;	
 #else
     struct stat s;
     if(stat(pathname, &s) == 0 && !S_ISDIR(s.st_mode))
       return pathname;
 #endif
+
     //free(pathname);
+
     if(*p == 0) break;
   }
   return 0;                                                    // Not found.
@@ -531,9 +541,9 @@ char *chargeFichier(char *_pNomFichier)
 }
 
 //------------------------------------------------------------------------------
-// load a file in memory 
-// input => _pNomFichier : filename
-// sortie <= _pMemoire   : ptr/integer 
+// load a file in memory / charge un fichier en memoire
+// input => _pNomFichier : nom du fichier / filename
+// sortie <= _pMemoire   : zone memoire ou est stockee le fichier (0=erreur)
 //------------------------------------------------------------------------------
 char *chargeFichier(char *_pNomFichier, unsigned int *pTaille)
 {
@@ -578,7 +588,7 @@ char *chargeFichier(char *_pNomFichier, unsigned int *pTaille)
   }
   close(_iHandle);
 #ifdef _VERBEUX_
-  if(iVerbeux > 1)
+  if(power_conf->verbose > 1)
     printf("linuxroutines/chargeFichier : file %s was loaded in memory\n", pathname);
 #endif
   //free(pathname);
@@ -624,7 +634,7 @@ int chargeFichier(char *_pNomFichier, char *_pMemoire)
   }
   close(_iHandle);
 #ifdef _VERBEUX_
-  if(iVerbeux > 1) printf("linuxroutines/chargeFichier : file %s was loaded in memory\n", pathname);
+  if(power_conf->verbose > 1) printf("linuxroutines/chargeFichier : file %s was loaded in memory\n", pathname);
 #endif
   //free(pathname);
   return 1;
@@ -660,7 +670,7 @@ void fps_affiche()
   time_end = SDL_GetTicks();
   duration = time_end - time_begin;
   fps = (1000.0 * iCompteurBoucle) / duration;
-  if(iVerbeux > 0)
+  if(power_conf->verbose)
   { printf("> linuxroutines.cpp/number of loops : %i\n", iCompteurBoucle);
     printf("> linuxroutines.cpp/running time    : %li\n", duration);
     printf("> linuxroutines.cpp/fps_affiche()   : frames per seconde : %g \n", fps);
@@ -718,7 +728,7 @@ void fps_affiche()
     }
   }
   //processeur & memoire physique du systeme .....................................
-  if(iVerbeux > 0)
+  if(power_conf->verbose)
   { printf("operating system   : %s %s\n", os_name, os_vers);
     printf("processor          : %s at %s Mhz with %.0f RAM\n", cpu, freq, mem);
     printf("number of loops    : %i\n", iCompteurBoucle);
