@@ -34,7 +34,7 @@ extern vaisseau         vj[NBR_MAX_J];                         //declaration de
 extern bool             option_change;                         //true=changement d'options a lieur
 extern bool             bar_nrj_player;
 extern image            vj1[NBR_MAX_VAIS_J][NBR_MAX_IMG_VAIS_J];
-extern option           aff_option[11];                        //tableau affichage des options
+extern option           aff_option[MAX_TYP_OF_OPTIONS];                        //tableau affichage des options
 extern int              liste_bou[MAX_BOULES_ON_SCREEN];       //liste de touts les 'bou' geres actuellement
 extern int              liste_can[MAX_CANONS_ON_SCREEN];       //liste de touts les 'can' geres actuellement
 extern int              bonusx;                                //mutliplicatreur des points
@@ -49,7 +49,7 @@ extern fonte            doublex[5];                            //tableau des dif
 extern char            *ecran;                                 //adresse de l'ecran physique
 extern int              cmpt_vbls_x2, cmpt_vbls_x4, aff_x2_rj, aff_x4_rj;       //variables utilisees pour la gestion des multiplicateurs
 extern fonte            options[MAX_TYP_OF_OPTIONS][NBR_IMAGES_OPTIONS];        // Dfinit le tableau des diffrentes images des options.
-extern option           aff_option[11];                        //Tableau utilise pour l'affichage des options pendant le jeu.
+//extern option           aff_option[11];                        //Tableau utilise pour l'affichage des options pendant le jeu.
 extern int              old_option;                            //Ancien numro d'option, utilise pour l'effacement dans le panneau d'options.
 
 //..............................................................................
@@ -375,13 +375,13 @@ void testBoutonOption()
           option_change = 1;
           if(vj[J1].vit_dep_vaisseau >= 5)                     //speed maxi ?
             Init_Anim_Option(0, 1);                            //yes, close option
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(SELECT);                                   //play sound with seal library
 #endif
         }
         else
         {
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(NOSELECT);
 #endif
         }
@@ -401,13 +401,13 @@ void testBoutonOption()
           {
             Init_Anim_Option(1, 1);
           }
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(SELECT);
 #endif
         }
         else
         {
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(NOSELECT);                                 //joue un son avec seal
 #endif
         }
@@ -428,13 +428,13 @@ void testBoutonOption()
           {                                                    // Demande que l'animation de fermeture de l'option tir avant s'effectue.
             Init_Anim_Option(2, TRUE);
           }
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(SELECT);                                   //joue un son avec seal
 #endif
         }
         else
         {
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(NOSELECT);                                 //joue un son avec seal
 #endif
         }
@@ -454,13 +454,13 @@ void testBoutonOption()
           {                                                    // Demande que l'animation de fermeture de l'option tir special avant s'effectue.
             Init_Anim_Option(3, TRUE);
           }
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(SELECT);                                   //joue un son avec seal
 #endif
         }
         else
         {
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(NOSELECT);                                 //joue un son avec seal
 #endif
         }
@@ -480,14 +480,14 @@ void testBoutonOption()
           {                                                    // Demande que l'animation de fermeture de l'option tir gauche s'effectue.
             Init_Anim_Option(4, TRUE);
           }
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(SELECT);                                   //joue un son avec seal
 #endif
         }
         else
         {                                                      // Joue le son qui indique que la selection de l'option est impossible.
 //                                                      if (sndfx) wt_ms_playeffect (fxhandle_impsel1,nbchannel+3,64L,PAN_RIGHT,15000) ;
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(NOSELECT);                                 //joue un son avec seal
 #endif
         }
@@ -507,13 +507,13 @@ void testBoutonOption()
           {                                                    // Demande que l'animation de fermeture de l'option tir spcial gauche s'effectue.
             Init_Anim_Option(5, TRUE);
           }
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(SELECT);                                   //joue un son avec seal
 #endif
         }
         else
         {
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(NOSELECT);                                 //joue un son avec seal
 #endif
         }
@@ -533,13 +533,13 @@ void testBoutonOption()
           {                                                    // Demande que l'animation de fermeture de l'option tir droit s'effectue.
             Init_Anim_Option(6, TRUE);
           }
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(SELECT);                                   //joue un son avec seal
 #endif
         }
         else
         {
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(NOSELECT);                                 //joue un son avec seal
 #endif
         }
@@ -559,13 +559,13 @@ void testBoutonOption()
           {                                                    // Demande que l'animation de fermeture de l'option tir spcial droit s'effectue.
             Init_Anim_Option(7, TRUE);
           }
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(SELECT);                                   //joue un son avec seal
 #endif
         }
         else
         {
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(NOSELECT);                                 //joue un son avec seal
 #endif
         }
@@ -585,13 +585,13 @@ void testBoutonOption()
           {                                                    // Demande que l'animation de fermeture de l'option tir arrire s'effectue.
             Init_Anim_Option(8, TRUE);
           }
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(SELECT);                                   //joue un son avec seal
 #endif
         }
         else
         {
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(NOSELECT);                                 //joue un son avec seal
 #endif
         }
@@ -611,13 +611,13 @@ void testBoutonOption()
           {                                                    // Demande que l'animation de fermeture de l'option tir spcial arrire s'effectue.
             Init_Anim_Option(9, TRUE);
           }
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(SELECT);                                   //joue un son avec seal
 #endif
         }
         else
         {
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(NOSELECT);                                 //joue un son avec seal
 #endif
         }
@@ -630,7 +630,7 @@ void testBoutonOption()
           // Donne le vaisseau suprieur au joueur.
           vj[J1].type_vaisseau++;
           vj[J1].metamorphose = TRUE;                          // Indique qu'une mtamorphose du vaisseau doit s'oprer.
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(VCHANGE1);                                 //joue un son avec seal
 #endif
           vj[J1].invincible = TEMPS_INVINCIBLE;                // Indique le temps pendant lequel le joueur est invincible.
@@ -723,13 +723,13 @@ void testBoutonOption()
             vj[J1].power_spec_arriere = 0;                     // Clip le tir spcial arriere du joueur.
           //On RAZ la variable utilisee pour doubler ou quadrupler le score du joueur.
           bonusx = 0;
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(SELECT);                                   //joue un son avec seal
 #endif
         }
         else
         {
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
           seal_joue(NOSELECT);                                 //joue un son avec seal
 #endif
         }
