@@ -1,9 +1,10 @@
 //*****************************************************************************
-// copyright (c) 1998-2004 TLK Games all rights reserved
+// copyright (c) 1998-2005 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "powermanga.cpp"
 // created      : ?
-// updates      : 2004-08-01
+// updates      : 2005-01-08
+// id		: $Id: powermanga.cpp,v 1.1.1.1 2005/01/25 05:53:49 gurumeditation Exp $
 //-----------------------------------------------------------------------------
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -22,9 +23,8 @@
 //*****************************************************************************
 //..............................................................................
 #include "powermanga.hpp"
-
+extern configfile*      power_conf;
 //..............................................................................
-extern int              fullscreen;                            // 1=full screen (use dga or real full screen with SDL)
 unsigned int            iJoueIntro = 1;                        //1=start anim / 2= end anom 
 unsigned int            iCodeTouche = 0;                       //code key pressed / code touche pressee
 unsigned int            iBoutonFeu = 0;                        //1=bouton de la manette de jeu enfonce
@@ -41,7 +41,7 @@ int                     iNumeroGardien;
 void                    _execute_congra(int);
 int                     iErreurInitialisation;                 //1=erreur a l'initialisation
 extern unsigned int     iOctetsParPixel;                       //nombre d'octets par pixels (1=256 couleurs / 2=65536 couleurs)
-extern _etbfonte1      *pEtbfonte1;                            //object handle 8x8 chars (about CTRL + A)
+extern _etbfonte1             *pEtbfonte1;         //(ETB)objet cpp geran affichage caracteres 8x8
 
 //..............................................................................
 // Variables utilisees pour la gestion generale du jeu *************************
@@ -128,8 +128,8 @@ float                   vit_star_field = 2.0;                  //vitesse du cham
 vaisseau_nmi            ve[MAX_NMI_ON_SCREEN];                 // Dclaration de la structure des vaisseaux ennemis.
 int                     liste_ve[MAX_NMI_ON_SCREEN];           // liste de tous les vaisseaux ennemis a gerer
 int                     cmpt_nmis;                             //compteur nombre d'ennemis
-short                   nbr_nmis = 0;                          //aliens current number
-int                     new_ve;                                //Indique l'indice du tableau corespondant  un nouvel objet 've'.
+short                   nbr_nmis = 0;                          // Indique le nombre d'enemis actuellement grs.
+int                     new_ve;                                // Indique l'indice du tableau corespondant  un nouvel objet 've'.
 explosion               xpl[MAX_NMI_ON_SCREEN];                //structure utilisee par les explosions
 int                     liste_xpl[MAX_NMI_ON_SCREEN];          //liste de tous les 'xpl' geres
 int                     cmpt_exps;                             //compteur du nombre d'explosions
@@ -163,7 +163,7 @@ int                     liste_can[MAX_CANONS_ON_SCREEN];       //liste de tous l
 str_canon               can[MAX_CANONS_ON_SCREEN];             //structure des canons.
 int                     new_can;                               //pointeur sur un nouvel element 'can'.
 int                     cmpt_canons;                           //compteur du nombre de canons
-option                  aff_option[11];                        //tableau pour afficher options 
+option                  aff_option[MAX_TYP_OF_OPTIONS];                        //tableau pour afficher options 
 int                     nbr_ve_spe_generes;                    //nombre de vaisseaux spciaux dj utiliss dans le jeu.
 short                   nbr_bonus = 0;                         //nombre de bonus actuellement grs.
 image                   bonus[MAX_TYP_OF_BONUS][NBR_IMAGES_BONUS];      //tableau des diffrentes images des bonus.
@@ -207,6 +207,11 @@ short                   ce_vais_act = 0;                       // Variable utili
 short						        cercle_px[] = {30,29,29,29,28,27,26,25,24,22,21,19,17,15,13,11,9,7,4,2,0,-2,-4,-7,-9,-11,-13,-15,-17,-19,-21,-22,-24,-25,-26,-27,-28,-29,-29,-29,-30,-29,-29,-29,-28,-27,-26,-25,-24,-22,-21,-19,-17,-15,-13,-11,-9,-7,-4,-2,0,2,4,7,9,11,13,15,17,19,21,22,24,25,26,27,28,29,29,29};
 short						        cercle_py[] = {0,2,4,7,9,11,13,15,17,19,21,22,24,25,26,27,28,29,29,29,30,29,29,29,28,27,26,25,24,22,21,19,17,15,13,11,9,7,4,2,0,-2,-4,-7,-9,-11,-13,-15,-17,-19,-21,-22,-24,-25,-26,-27,-28,-29,-29,-29,-30,-29,-29,-29,-28,-27,-26,-25,-24,-22,-21,-19,-17,-15,-13,-11,-9,-7,-4,-2};
 
+
+// game language
+char			Lang[8];
+
+
 //******************************************************************************
 // "upDateFrame" : the main loop of game / boucle principale du jeu
 //******************************************************************************
@@ -442,7 +447,7 @@ int UpdateFrame()
     if(vj[J1].type_vaisseau != V1J)                            //le vaisseau n'est pas le premier vaisseau ?
     {
       vj[J1].type_vaisseau--;                                  //non, on regresse au vaisseau inferieur
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
       seal_joue(VCHANGE2);                                     //joue un son avec seal
 #endif
       vj[J1].metamorphose = 1;                                 //indique une metamorphose du vaisseau
@@ -555,16 +560,15 @@ int UpdateFrame()
 
   
 #ifdef SDL_TLK
-  //if ((touch[39]) && (touche_ctrl))
-  if((touch[39]) && !_score::isInputName())
-  {  
-    if(fullscreen)
-      fullscreen = 0;
-    else
-      fullscreen = 1;
-    init_video_mode();
-  }
-  touch[39] = 0;
+	//if ((touch[39]) && (touche_ctrl))
+	if((touch[39]) && !_score::isInputName())
+	{	if(power_conf->fullscreen)
+			power_conf->fullscreen = 0;
+		else
+			power_conf->fullscreen = 1;
+		init_video_mode();
+	}
+	touch[39] = 0;
 #endif
   
   
@@ -655,16 +659,14 @@ int UpdateFrame()
   touchesTriches();
 #endif
 
-  //Gestion des tirs du joueur (JMM) --------------------------------------------
+	//handle weapon's player ship
 #ifdef DEVELOPPEMENT
-  if(!grid_editor && !curv_editor && !game_over_player_one && !player_pause
-     && etat_menu == MENU_OFF && _score::getActionExecution() == 0)
+	if(!grid_editor && !curv_editor && !game_over_player_one && !player_pause
+		&& etat_menu == MENU_OFF && _score::getActionExecution() == 0)
 #else
-  if(!game_over_player_one && !player_pause && etat_menu == MENU_OFF
-     && _score::getActionExecution() == 0)
+	if(!game_over_player_one && !player_pause && etat_menu == MENU_OFF
+		&& _score::getActionExecution() == 0)
 #endif
-  {
-    tirsJoueur();
-  }
-  return 1;
+		tirsJoueur();
+	return 1;
 }
