@@ -1,12 +1,12 @@
 //******************************************************************************
-// copyright (c) 2003-2004 TLK Games all rights reserved
+// copyright (c) 2003-2005 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
-// file         : "seal.cpp"
-// created      : 2003-06-27
-// updates      : 2004-08-01
+// file		: "seal.cpp"
+// created	: 2003-06-27
+// updates	: 2005-01-09
+// id		: $Id: sdl_mixer.cpp,v 1.1.1.1 2005/01/25 05:55:02 gurumeditation Exp $
 //-----------------------------------------------------------------------------
-// description  : gestion modules et effets sonores avec sdl_mixer
-//                manage sound's effects and music's modules with sdl_mixer
+// description	: manage sound's effects and music's modules with sdl_mixer
 //-----------------------------------------------------------------------------
 // functions :  seal_init()
 //              seal_initialise(int)
@@ -14,9 +14,9 @@
 //              seal_exec()
 //              seal_kill()
 //              seal_restaure()
-//              seal_joue(unsigned int)
+//              seal_joue(Uint32)
 //-----------------------------------------------------------------------------
-// liste des fonctions utilisant seal_joue(unsigned int) :
+// liste des fonctions utilisant seal_joue(Uint32) :
 // - New_Element_Tir()  "powermanga sub2.cpp"
 // - Add_Ve_Special()   "powermanga sub1.cpp"
 // - Add_Explosion()    "powermanga sub2.cpp"
@@ -39,35 +39,35 @@
 //******************************************************************************
 //..............................................................................
 #include "powermanga.hpp"
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
 #include <SDL/SDL.h>
 #include <SDL/SDL_thread.h>
-#include <SDL/SDL_mixer.h>
+#include <SDL_mixer.h>
 //..............................................................................
-extern unsigned int     iVerbeux;                              //1=affiche les arguments
 extern short            touch[];                               //tableau des flags des touches du clavier.
 extern int              quit_game;                             //true=demande a quitter le jeu
 extern bool             aff_game_over;                         //true=affichage du game over en cours
 extern bool             player_pause;                          //true=pause en cours
 extern int              etat_menu;                             //MENU_OFF(false)=menu inactif ; MENU_ON(true)=menu actif
-extern unsigned int     seal_thread_run;                       //1=thread play music running
+extern Uint32     seal_thread_run;                       //1=thread play music running
+
 //constantes ...................................................................
-const unsigned int      iNOMBRESONS = 28;
-const unsigned int      iBRUITAGESVOIX = 4;                    //nombre de voix pour les bruitages (avec module)
-const unsigned int      iBRUITAGESVOIX2 = 8;                   //nombre de voix pour les bruitages (sans module)
+const Uint32      iNOMBRESONS = 28;
+const Uint32      iBRUITAGESVOIX = 4;                    //nombre de voix pour les bruitages (avec module)
+const Uint32      iBRUITAGESVOIX2 = 8;                   //nombre de voix pour les bruitages (sans module)
+
 //..............................................................................
-unsigned int            iBruitagesVoix;                        //nombre de voix pour les bruitages
+Uint32            iBruitagesVoix;                        //nombre de voix pour les bruitages
 Mix_Music              *lpModule;
-unsigned int            utilise_seal = 1;                      //1=alors utilise seal
-unsigned int            iFlagBruitages[iNOMBRESONS];
-unsigned int            iFlagMusique;                          //1=alors musique active
+Uint32            iFlagBruitages[iNOMBRESONS];
+Uint32            iFlagMusique;                          //1=alors musique active
 int                     iNumeroModule;                         //numero du module en cours (0 a n) -1=pas de module charge
 int                     iNumeroModule2;                        //numero du module en cours (0 a n) -1=pas de module charge
-unsigned int            iChangeSonMusique;                     //1=on active/desactive musique
-unsigned int            iVolumeModule;
-unsigned int            iVolumeModule2;
-unsigned int            iTailleSons;                           //taille des sons
-unsigned int            nDeviceId = 0;
+Uint32            iChangeSonMusique;                     //1=on active/desactive musique
+Uint32            iVolumeModule;
+Uint32            iVolumeModule2;
+Uint32            iTailleSons;                           //taille des sons
+Uint32            nDeviceId = 0;
 
 //noms des fichiers sons........................................................
 char *pFichiersSons[iNOMBRESONS] =
@@ -129,8 +129,8 @@ char *SealErrorText[14] =
 
 //..............................................................................
 Mix_Chunk              *pSons[iNOMBRESONS];                    //structures de tous les sons
-unsigned int            fSons[iNOMBRESONS];                    //flag pour chaque son 1=charge
-extern unsigned int     iVerbeux;                              //1=verbose mode ; 2=super verbose mode
+Uint32		fSons[iNOMBRESONS];                    //flag pour chaque son 1=charge
+extern configfile*	power_conf;
 
 //prototypes des fonctions loacales ............................................
 int                     seal_initialise(int);
@@ -145,8 +145,8 @@ char                   *locate_data_file(const char *const name);
 //------------------------------------------------------------------------------
 int seal_init()
 {
-  unsigned int i;
-  if(utilise_seal)
+  Uint32 i;
+  if(!power_conf->nosound)
   { iVolumeModule = MIX_MAX_VOLUME;
     iVolumeModule2 = MIX_MAX_VOLUME;
     iChangeSonMusique = 0;
@@ -157,7 +157,7 @@ int seal_init()
     if(SDL_Init(SDL_INIT_AUDIO | SDL_INIT_NOPARACHUTE) < 0)
     { fprintf(stderr, "sdl_mixer.cpp/seal_init(): Ainitialise() failed: %s\n", 
         SDL_GetError());
-      utilise_seal = 0;
+      power_conf->nosound = 1;
       return 1;
     }
     int audio_rate = 44100;
@@ -165,7 +165,7 @@ int seal_init()
     int audio_buffers = 4096;
     if(Mix_OpenAudio(audio_rate, audio_format, 2, audio_buffers))
     { fprintf(stderr,"sdl_mixer.cpp/seal_init(): %s\n",SDL_GetError());
-      utilise_seal = 0;
+      power_conf->nosound = 1;
 		  SDL_Quit();
 		  return 1;
 	  }
@@ -173,20 +173,20 @@ int seal_init()
     //if(seal_initialise(iNumeroModule2) == FALSE)
     if(!seal_JoueModule(0))
       return FALSE;
-    if(utilise_seal == 0)
+    if(power_conf->nosound)
       return 1;
 
-    //loading "waves" files ----------------------------------------------------
-    iTailleSons = 0; //waves total size 
+    //charge les fichiers "waves" ----------------------------------------------
+    iTailleSons = 0;                                           //taille total des sons
     for(i = 0; i < iNOMBRESONS; i++)
     { char *_pNom = pFichiersSons[i];
       char *pathname = locate_data_file(_pNom);
       if(!pathname)
       { fprintf(stderr,
-          "! error locating data file %s\n",
-           _pNom);
+           "!sdl_mixer.cpp/seal_init() / error locating data file %s\n",
+            _pNom);                                
         return FALSE;
-      }
+      }                                           
       Mix_Chunk *_pSon = Mix_LoadWAV(pathname);
       if(!_pSon) {
         afficheErreur(pathname,
@@ -198,7 +198,7 @@ int seal_init()
       fSons[i] = 1;                                            //ok, son charge
     }
   }
-  if(iVerbeux)
+  if(power_conf->verbose)
     printf("> sdl_mixer.cpp/seal_init(): successful initialization!\n");
   return TRUE;
 }
@@ -231,9 +231,9 @@ int seal_chargeModule(int _iNumeroModule)
     if(!pathname)
     { fprintf(stderr,
         "! error locating data file %s\n",
-         _pNom);
+        _pNom);
       return FALSE;
-    }
+    } 
     lpModule = Mix_LoadMUS(pathname);
     if(!lpModule)
     { fprintf(stderr,
@@ -242,7 +242,7 @@ int seal_chargeModule(int _iNumeroModule)
       return FALSE;
     }
 #ifdef _VERBEUX_
-    if(iVerbeux > 0)
+    if(power_conf->verbose > 0)
       fprintf(stdout,
         "> sdl_mixer.cpp/seal_chargeModule() loaded module: %s\n",
         _pNom);
@@ -280,8 +280,8 @@ int seal_JoueModule(int _iNumeroModule)
 //------------------------------------------------------------------------------
 void seal_exec()
 {
-  unsigned int i;
-  if(utilise_seal)
+  Uint32 i;
+  if(!power_conf->nosound)
   {
     //regle volume du module
     if(iFlagMusique && etat_menu == MENU_OFF
@@ -307,13 +307,12 @@ void seal_exec()
     for(i = 0; i < iNOMBRESONS; i++)
     {
       if(iFlagBruitages[i])
-      { if (Mix_PlayChannel(-1, pSons[i], 0) == -1) {
+      { if (Mix_PlayChannel(-1,pSons[i], 0) == -1) {
           /*fprintf(
             stderr,
             "! sdl_mixer.cpp/seal_exec(): Mix_PlayChannel, %s\n",
-            Mix_GetError());
-          */
-	}
+            Mix_GetError());*/
+        }
         iFlagBruitages[i] = 0;
       }
     }
@@ -347,24 +346,21 @@ void seal_exec()
 }
 
 //------------------------------------------------------------------------------
-// seal : libere tout
+// SDL_mixer: release sounds
 //------------------------------------------------------------------------------
 void seal_kill()
 {
-  unsigned int i;
-  if(utilise_seal)
-  {
-    for(i = 0; i < iNOMBRESONS; i++)
-    {
-      if(fSons[i] == 1)                                        //le son a ete charge ?
-      {
-        Mix_FreeChunk(pSons[i]);
-        fSons[i] = 0;                                          //ok, son libere
-      }
-    }
-    Mix_CloseAudio();
-    SDL_Quit();
-  }
+	Uint32 i;
+	if(!power_conf->nosound)
+	{	for(i = 0; i < iNOMBRESONS; i++)
+		{	if(fSons[i] == 1)	//sound was loaded?
+			{	Mix_FreeChunk(pSons[i]);
+				fSons[i] = 0;	//ok, sound released
+			}
+		}
+		Mix_CloseAudio();
+		SDL_Quit();
+	}
 }
 
 //------------------------------------------------------------------------------
@@ -378,7 +374,7 @@ void seal_restaure()
 // seal : demande a jouer un son
 // input => iNumeroSon : numero du son de 0 a iNOMBRESONS
 //------------------------------------------------------------------------------
-void seal_joue(unsigned int iNumeroSon)
+void seal_joue(Uint32 iNumeroSon)
 {
   if(!aff_game_over && !player_pause && _score::getActionExecution() == 0
      && etat_menu == MENU_OFF)
