@@ -1,9 +1,10 @@
 //*****************************************************************************
-// copyright (c) 1998-2004 TLK Games all rights reserved
+// copyright (c) 1998-2005 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
-// file         : "sdl_tlk.cpp"
-// created      : 2003-07-09
-// updates      : 2004-08-01
+// file		: "sdl_tlk.cpp"
+// created	: 2003-07-09
+// updates	: 2005-01-26
+// id		: %Id$
 //-----------------------------------------------------------------------------
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -47,9 +48,13 @@ unsigned int            iLargeurEcran = 0;                     //largeur de notr
 unsigned int            iHauteurEcran = 0;                     //hauteur de notre fenetre
 unsigned int            iLargeurEcranTotal = 0;                //taille d'une ligne du buffer 'ecran_ram'
 int                     vmode = 1;                             //0=resolution de 320x200 / 1=640*400 / 2=640*400 (double pixels)
+#ifdef WIN32
+Sint32			vmode2 = 1;				// si vmode = 1 ==> 0 = 640x400 / 1 = 640x480
+#else
+Sint32			vmode2 = 0;
+#endif
 
 //...............................................................................
-int                     fullscreen = 1;                        //1=marche en plein ecran
 char                   *ecran_playanim = 0;                    //memory buffer 320*200
 char                   *ecran_ram640 = 0;                      //memory buffer 640*400
 char                   *ecran_scr = 0;                         //memory buffer 320*016 (score bar-line)
@@ -59,7 +64,6 @@ unsigned int            iAffiche = 0;                          //0=update displa
 //..............................................................................
 extern bool             bar_nrj_player;
 extern char            *ecran_ram;                             //adresse du buffer de 512x440 (XImage)
-extern unsigned int     iVerbeux;                              //1=affiche les arguments
 extern short            touch[500];                            //tableau des flags de toutes les touches clavier
 extern int              quit_game;                             //1=demande a quitter le jeu
 extern unsigned int     iCodeTouche;                           // code touche pressee
@@ -70,10 +74,13 @@ extern unsigned int     iCodeTouche;                           // code touche pr
 void                    initialiseCurseurBlanc();
 void                    affiche_ecran();
 void                    afficheAnim();
+
 void                    fenetre320x200();
 void                    fenetre640x400();
+
 void                    dga320x200();
 void                    dga640x400();
+
 SDL_Surface            *creeXImage(unsigned int _iLarge,
                                    unsigned int _iHaute);
 void                    libereXImage(SDL_Surface *_pXImage);
@@ -89,6 +96,7 @@ extern unsigned char   *image1;                                //pointer to the
 extern unsigned int     iBarreNrjJoueurXWindow;                //1=update player's enerny bar-line
 extern unsigned int     iBarreNrjGardienXWindow;               //1=update bigboss's energy bar-line
 extern unsigned int     iScoreXWindow;                         //1=update player's score points
+extern configfile*      power_conf;
 
 //...............................................................................
 SDL_Color              *pXColor = 0;                           //color table
@@ -118,6 +126,7 @@ int xw_init()
   }
 
 
+
   // initialize SDL screen .....................................................
   
   //if(SDL_Init(SDL_INIT_VIDEO|SDL_INIT_TIMER|SDL_INIT_NOPARACHUTE) <0 )
@@ -141,7 +150,7 @@ int xw_init()
     return 0;
   }
 #ifdef _VERBEUX_
-  if(iVerbeux == 1)
+  if(power_conf->verbose)
   { printf
       ("> sdl_tlk.cpp/xw_init(): depth of screen: %i; bytes per pixel: %i;\n",
        iProfondeur, iOctetsParPixel);
@@ -152,68 +161,88 @@ int xw_init()
 
   SDL_EnableUNICODE(1);
 #ifdef _VERBEUX_
-  if(iVerbeux == 1)
+  if(power_conf->verbose)
     afficheMessage("> sdl_tlk.cpp/xw_init(): successful initialization!");
 #endif
   return 1;
 }
 
 //------------------------------------------------------------------------------
-// SDL : initialise le mode video / initialize vide mode
-// sortie / output <= 0 : erreur
+// SDL: initialize video mode
+// return: 0 = > error / 1 => no error
 //------------------------------------------------------------------------------
 int init_video_mode()
 {
-  Uint32 flag;
-  Uint32 bpp;
+	Uint32 flag;
+	Uint32 bpp;
+
+	//##############################################################
+	// 640x400 => 640x480 (win32 only)
+	//##############################################################
+	if ((vmode) && (vmode2)) {
+		iHauteurEcran = 480;
+	}
+	
+	//##############################################################
+	// test video mode
+	//##############################################################
+	flag = SDL_ANYFORMAT;
+	if(iOctetsParPixel == 1)
+		flag = flag | SDL_HWPALETTE;
+	if(power_conf->fullscreen > 0)
+		flag = flag | SDL_FULLSCREEN; 
+	bpp = SDL_VideoModeOK(iLargeurEcran, iHauteurEcran, iProfondeur2, flag);
+	if(!bpp)
+	{	if(!power_conf->fullscreen)
+		{	fprintf(stderr,
+				"sdl_tlk.cpp/init_video_mode(): SDL_VideoModeOK() return: %s",
+				SDL_GetError());
+			return 0;
+		}
+		else 
+		{
+			// fullscreen fail, try in window mode
+			power_conf->fullscreen = 0;
+			flag = SDL_ANYFORMAT;
+			if(iOctetsParPixel == 1)
+				flag = flag | SDL_HWPALETTE;
+			bpp = SDL_VideoModeOK(iLargeurEcran, iHauteurEcran, iProfondeur2, flag);
+			if(!bpp)
+			{	fprintf(stderr,
+					"sdl_tlk.cpp/init_video_mode(): SDL_VideoModeOK() return: %s",
+					SDL_GetError());
+				return 0;
+			}
+		}
+	}
+
   
-  // test le mode video --------------------------------------------------------  
-  flag = SDL_ANYFORMAT;
-  if(iOctetsParPixel == 1)
-    flag = flag | SDL_HWPALETTE;
-  if(fullscreen > 0)
-    flag = flag | SDL_FULLSCREEN; 
-  bpp = SDL_VideoModeOK(iLargeurEcran, iHauteurEcran, iProfondeur2, flag);
-  if(!bpp)
-  { 
-    if(!fullscreen)
-    { fprintf(stderr,
-        "sdl_tlk.cpp/xw_init() : SDL_VideoModeOK() Mode not available : %s",
-        SDL_GetError());
-      return 0;
-    }
-    // echec en plein ecran, ressaie en mode fenetree
-    else 
-    { fullscreen = 0;
-      flag = SDL_ANYFORMAT;
-      if(iOctetsParPixel == 1)
-        flag = flag | SDL_HWPALETTE;
-      bpp = SDL_VideoModeOK(iLargeurEcran, iHauteurEcran, iProfondeur2, flag);
-      if(!bpp)
-      { fprintf(stderr,
-          "sdl_tlk.cpp/xw_init() : SDL_VideoModeOK() Mode not available : %s",
-          SDL_GetError());
-        return 0;
-      }
-    }
-  }
+	//##############################################################
+	// initialize video mode
+	//##############################################################
+	pPowerMangaDisplay =
+		SDL_SetVideoMode(iLargeurEcran, iHauteurEcran, iProfondeur2, flag);
+	if(!pPowerMangaDisplay)
+	{	fprintf(stderr,
+			"sdl_tlk.cpp/init_video_mode(): SDL_SetVideoMode() return %s\n",
+			SDL_GetError());
+		return 0;
+	}
   
-  // initialie le mode video ---------------------------------------------------
-  pPowerMangaDisplay =
-    SDL_SetVideoMode(iLargeurEcran, iHauteurEcran, iProfondeur2, flag);
-  if(!pPowerMangaDisplay)
-  { fprintf(stderr,
-      "ecran_hard::ecran_init() : SDL_SetVideoMode() failed: %s\n",
-    SDL_GetError());
-    return 0;
-  }
-  SDL_WM_SetCaption(nomfenetre, nomfenetre);
-  iAffiche = 0; // force refresh all the screen
-  if(fullscreen > 0)
-    SDL_ShowCursor(SDL_DISABLE);
-  else 
-    SDL_ShowCursor(SDL_ENABLE);  
-  return 1;
+	//##############################################################
+  	// restore valid height screen (win32 only)
+	//##############################################################
+	if ((vmode) && (vmode2)) {
+		iHauteurEcran = HAUT_ECRAN_PHY * 2;
+	}
+
+	SDL_WM_SetCaption(nomfenetre, nomfenetre);
+	iAffiche = 0; // force refresh all the screen
+	if(power_conf->fullscreen > 0)
+		SDL_ShowCursor(SDL_DISABLE);
+	else 
+		SDL_ShowCursor(SDL_ENABLE);  
+	return 1;
 }
 
 //------------------------------------------------------------------------------
@@ -428,7 +457,7 @@ void key_status(Uint8 *k)
   touch[47]  = k[SDLK_p];                 //P P=PAUSE
   touch[58]  = k[SDLK_q];                 //Q CTRL+Q gameover
   touch[60]  = k[SDLK_s];                 //S CTRL+S coupe la musique
-    
+
   touch[73]  |= k[SDLK_KP6];              //right arrow 
   touch[71]  |= k[SDLK_KP4];              //left arrow
   touch[55]  |= k[SDLK_KP8];              //up arrow
@@ -455,7 +484,7 @@ void affiche_ecran()
         break;                                               // window 320*200
       case 1:
         fenetre640x400();
-        break;                                               // window 640x480
+        break;                                               
     }
   }
 }
@@ -501,20 +530,33 @@ void afficheAnim()
     }
     break;
     
-    //mode 640x400
+    //mode 640x400    
     case 1:
       { copy2X(ecran_playanim, ecran_ram640, 320, 200, 0,
                iLargeurEcran * iOctetsParPixel * 2 -
                (iLargeurEcran * iOctetsParPixel));
-      rsour.x = 0; rsour.y = 0;
+      rsour.x = 0; 
+	  
+	  if (vmode2) 
+         rsour.y = 40;
+	  else 
+	     rsour.y = 0;
+
       rsour.w = iLargeurEcran; rsour.h = iHauteurEcran;
       v = SDL_BlitSurface(pEcranXImage640, &rsour, pPowerMangaDisplay, &rsour);
       if(v < 0)
         fprintf(stderr, "BlitSurface error: %s\n", SDL_GetError());
 
       }
-      SDL_UpdateRect(pPowerMangaDisplay, 0, 0, 
+	  
+	    if (vmode2) 
+			SDL_UpdateRect(pPowerMangaDisplay, 0, 40, 
+                     pPowerMangaDisplay->w, pPowerMangaDisplay->h - 40);
+		else
+			SDL_UpdateRect(pPowerMangaDisplay, 0, 0, 
                      pPowerMangaDisplay->w, pPowerMangaDisplay->h);
+	  
+
         break;
     }
 }
@@ -633,6 +675,7 @@ void fenetre320x200()
 void fenetre640x400()
 {
   Uint32 v;
+  int		starty;
   SDL_Rect rdest;
   SDL_Rect rsour;
   char *_pSource =
@@ -647,10 +690,20 @@ void fenetre640x400()
   );
 
 
+  // mode 640x480
+  if (vmode2) 
+	  starty = 40;
+  else 
+	  starty = 0;
+
+
+
   if(iAffiche)
   { rsour.x = 0; rsour.y = 32; 
     rsour.w = LARG_ECR_RAM * 2; rsour.h = HAUT_ECR_RAM * 2;
-    v = SDL_BlitSurface(pEcranXImage640, &rsour, pPowerMangaDisplay, &rsour);
+	rdest.x = 0; rdest.y = 32 + starty; 
+    rdest.w = LARG_ECR_RAM * 2; rdest.h = HAUT_ECR_RAM * 2;
+    v = SDL_BlitSurface(pEcranXImage640, &rsour, pPowerMangaDisplay, &rdest);
     if(v < 0)
       fprintf(stderr, "BlitSurface error: %s\n", SDL_GetError());
 
@@ -664,7 +717,7 @@ void fenetre640x400()
              (iLargeurEcran * 2 * iOctetsParPixel) -
              128 * iOctetsParPixel * 2);
       rsour.x = 68 * 2; rsour.y = 0; rsour.w = 128 * 2; rsour.h = 16 * 2;
-      rdest.x = 68 * 2; rdest.y = 0; rdest.w = 128 * 2; rdest.h = 16 * 2;
+      rdest.x = 68 * 2; rdest.y = starty; rdest.w = 128 * 2; rdest.h = 16 * 2;
       v = SDL_BlitSurface(pEcranXImage640, &rsour, pPowerMangaDisplay, &rdest);
       if(v < 0)
         fprintf(stderr, "BlitSurface error: %s\n", SDL_GetError());
@@ -681,7 +734,9 @@ void fenetre640x400()
              14 * iOctetsParPixel * 2);
       rsour.x = (LARG_ECR_RAM + 41) * 2; rsour.y = (SCR_HAUTE + 171) * 2;
       rsour.w = 14 * 2; rsour.h = 8 * 2;
-      v = SDL_BlitSurface(pEcranXImage640, &rsour, pPowerMangaDisplay, &rsour);
+	  rdest.x = (LARG_ECR_RAM + 41) * 2; rdest.y = (SCR_HAUTE + 171) * 2 + starty;
+      rdest.w = 14 * 2; rdest.h = 8 * 2;
+      v = SDL_BlitSurface(pEcranXImage640, &rsour, pPowerMangaDisplay, &rdest);
       if(v < 0)
         fprintf(stderr, "BlitSurface error: %s\n", SDL_GetError());
       iBonusX2Affiche = 0;
@@ -698,7 +753,9 @@ void fenetre640x400()
              14 * iOctetsParPixel * 2);
       rsour.x = (LARG_ECR_RAM + 41) * 2; rsour.y = (SCR_HAUTE + 5) * 2;
       rsour.w = 14 * 2; rsour.h = 8 * 2;
-      v = SDL_BlitSurface(pEcranXImage640, &rsour, pPowerMangaDisplay, &rsour);
+	  rdest.x = (LARG_ECR_RAM + 41) * 2; rdest.y = (SCR_HAUTE + 5) * 2 + starty;
+      rdest.w = 14 * 2; rdest.h = 8 * 2;
+      v = SDL_BlitSurface(pEcranXImage640, &rsour, pPowerMangaDisplay, &rdest);
       if(v < 0)
         fprintf(stderr, "BlitSurface error: %s\n", SDL_GetError());
       iBonusX4Affiche = 0;
@@ -718,7 +775,9 @@ void fenetre640x400()
              28 * iOctetsParPixel * 2);
       rsour.x = (LARG_ECR_RAM + _iOptionX) * 2; rsour.y = (SCR_HAUTE + _iOptionY) * 2;
       rsour.w = 28 * 2; rsour.h = 28 * 2;
-      v = SDL_BlitSurface(pEcranXImage640, &rsour, pPowerMangaDisplay, &rsour);
+	  rdest.x = (LARG_ECR_RAM + _iOptionX) * 2; rdest.y = (SCR_HAUTE + _iOptionY) * 2 + starty;
+      rdest.w = 28 * 2; rdest.h = 28 * 2;
+      v = SDL_BlitSurface(pEcranXImage640, &rsour, pPowerMangaDisplay, &rdest);
       if(v < 0)
         fprintf(stderr, "BlitSurface error: %s\n", SDL_GetError());
     }
@@ -736,7 +795,9 @@ void fenetre640x400()
              100 * iOctetsParPixel * 2);
       rsour.x = 210 * 2; rsour.y = 3 * 2;
       rsour.w = 100 * 2; rsour.h = 9 * 2;
-      v = SDL_BlitSurface(pEcranXImage640, &rsour, pPowerMangaDisplay, &rsour);
+	  rdest.x = 210 * 2; rdest.y = 3 * 2 + starty;
+      rdest.w = 100 * 2; rdest.h = 9 * 2;
+      v = SDL_BlitSurface(pEcranXImage640, &rsour, pPowerMangaDisplay, &rdest);
       if(v < 0)
         fprintf(stderr, "BlitSurface error: %s\n", SDL_GetError());
     }
@@ -752,7 +813,7 @@ void fenetre640x400()
              45 * iOctetsParPixel * 2);
       rsour.x = 10 * 2; rsour.y = 3 * 2;
       rsour.w = 45 * 2; rsour.h = 9 * 2;
-      rdest.x = 10 * 2; rdest.y = 3 * 2;
+      rdest.x = 10 * 2; rdest.y = 3 * 2 + starty;
       rdest.w = 45 * 2; rdest.h = 9 * 2;
       v = SDL_BlitSurface(pEcranXImage640, &rsour, pPowerMangaDisplay, &rdest);
       if(v < 0)
@@ -773,16 +834,20 @@ void fenetre640x400()
            iLargeurEcran * iOctetsParPixel * 2 -
            (OPT_LARGE * 2 * iOctetsParPixel));
     rsour.x = 0; rsour.y = 0; rsour.w = iLargeurEcran; rsour.h = iHauteurEcran;
-    rdest.x = 0; rdest.y = 0; rdest.w = iLargeurEcran; rdest.h = iHauteurEcran;
+    rdest.x = 0; rdest.y = starty; rdest.w = iLargeurEcran; rdest.h = iHauteurEcran;
     v = SDL_BlitSurface(pEcranXImage640, &rsour, pPowerMangaDisplay, &rdest);
     if(v < 0)
       fprintf(stderr, "BlitSurface error: %s\n", SDL_GetError());     
     iAffiche = 1;
     iOptionIndex = -1;
   }     
-  SDL_UpdateRect(pPowerMangaDisplay, 0, 0, pPowerMangaDisplay->w, pPowerMangaDisplay->h);    
+
+  SDL_UpdateRect(pPowerMangaDisplay, 0, starty, pPowerMangaDisplay->w, pPowerMangaDisplay->h - starty);    
 }
 
+
+
+
 //------------------------------------------------------------------------------
 // SDL : ferme l'affichage sous SDL
 //------------------------------------------------------------------------------
@@ -799,7 +864,7 @@ int xw_kill()
   pEcranOptXImage = 0;
   SDL_Quit();
 #ifdef _VERBEUX_
-  if(iVerbeux > 0)
+  if(power_conf->verbose)
     afficheMessage("> sdl_tlk.cpp/xw_kill() / SDL_Quit");
 #endif
   return 1;
@@ -941,7 +1006,7 @@ SDL_Surface *creeXImage(unsigned int _iLarge, unsigned int _iHaute)
   pListeXImage[_iXimageLibre] = _pXImage;
   iNombreXImage++;
 #ifdef _VERBEUX_
-  if(iVerbeux > 0)
+  if(power_conf->verbose)
     fprintf(stdout,
       "> sdl_tlk.cpp/creeXImage(): SDL_CreateRGBSurface(%i,%i,%i)\n",
       _iLarge,_iHaute,iProfondeur2);
@@ -965,7 +1030,7 @@ void libereXImage(SDL_Surface *_pXImage)
       pListeXImage[_iIndex] = 0;
       iNombreXImage--;
 #ifdef _VERBEUX_
-      if(iVerbeux > 0)
+      if(power_conf->verbose)
         fprintf(stdout,
           "> sdl_tlk.cpp/libereXImage(): SDL_FreeSurface; %i,%i\n", w, h);
 #endif
@@ -991,7 +1056,7 @@ void libereXImages()
       pListeXImage[_iIndex] = 0;
       iNombreXImage--;
 #ifdef _VERBEUX_
-      if(iVerbeux > 0)
+      if(power_conf->verbose)
         fprintf(stdout,
           "> sdl_tlk.cpp/libereXImage(): SDL_FreeSurface; %i,%i\n", w, h);
 #endif
