@@ -1,9 +1,10 @@
 //*****************************************************************************
-// copyright (c) 1998-2002 TLK Games all rights reserved
+// copyright (c) 1998-2005 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "tirsJoueurs.cpp"
 // created      : ?
-// updates      : 2002-08-02
+// updates      : 2005-01-08
+// id		: $Id: tirsJoueur.cpp,v 1.1.1.1 2005/01/25 05:55:27 gurumeditation Exp $
 //-----------------------------------------------------------------------------
 // description  : ship's fires run-time 
 //-----------------------------------------------------------------------------
@@ -43,7 +44,7 @@ void tirsJoueur()
     {
       vj[J1].cad_tir = 50 - (vj[J1].type_vaisseau * 5 + 5);    // nombre de VBLs necessaires avant que le vaisseau puisse a nouveau tirer
       vj[J1].cad_tir_spec = vj[J1].cad_tir >> 1;               // nombre de VBLs necessaires avant que le vaisseau puisse a nouveau tirer
-#ifdef UTILISE_SEAL
+#ifdef USE_SDLMIXER
       seal_joue(TIR2);                                         //joue un son avec seal
 #endif
       // Test suivant le type de vaisseau utilis par le joueur.
