@@ -1,9 +1,10 @@
 //*****************************************************************************
-// copyright (c) 1998-2002 TLK Games all rights reserved
+// copyright (c) 1998-2005 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "vaisseau.cpp"
 // created      : ?
-// updates      : 2002-08-02
+// updates      : 2005-01-10
+// id		: $Id: vaisseau.cpp,v 1.1.1.1 2005/01/25 05:55:32 gurumeditation Exp $
 //-----------------------------------------------------------------------------
 // functions   : void  vaisseau_restaure()
 //               void  vaisseau_invincibilite()
@@ -193,8 +194,8 @@ void boule_execution()
               tirs[new_tir].spr.img[l] = (image *) & fire[V1TN1][l];    // Corespond au Tir 2 puissance 1.
             }
             tirs[new_tir].spr.etat_dommages = tirs[new_tir].spr.pow_of_dest;    // Indique l'tat de domages du sprite.
-            tirs[new_tir].spr.pilote = 0;                      // Indique par qui est dirig le sprite.
-            tirs[new_tir].spr.mode_commande = 0;               // Indique le moyen par lequel on fait dplacer le sprite.
+            //tirs[new_tir].spr.pilote = 0;                      // Indique par qui est dirig le sprite.
+            //tirs[new_tir].spr.mode_commande = 0;               // Indique le moyen par lequel on fait dplacer le sprite.
             tirs[new_tir].spr.img_act = 0;                     // Indique l'image actuelle.
             tirs[new_tir].spr.nbr_tot_vbl = 4;                 // Indique le nombre de VBL qu'il faut pour passer  l'image suivante.
             tirs[new_tir].spr.nbr_vbl_act = 0;                 // Indique le nombre de VBL comptes actuellement.
@@ -341,8 +342,8 @@ void canon_execution()
               tirs[new_tir].spr.img[l] = (image *) & fire[V1TN1][l];    // Corespond au Tir 2 puissance 1.
             }
             tirs[new_tir].spr.etat_dommages = tirs[new_tir].spr.pow_of_dest;    // Indique l'tat de domages du sprite.
-            tirs[new_tir].spr.pilote = 0;                      // Indique par qui est dirig le sprite.
-            tirs[new_tir].spr.mode_commande = 0;               // Indique le moyen par lequel on fait dplacer le sprite.
+            //tirs[new_tir].spr.pilote = 0;                      // Indique par qui est dirig le sprite.
+            //tirs[new_tir].spr.mode_commande = 0;               // Indique le moyen par lequel on fait dplacer le sprite.
             tirs[new_tir].spr.img_act = 0;                     // Indique l'image actuelle.
             tirs[new_tir].spr.nbr_tot_vbl = 4;                 // Indique le nombre de VBL qu'il faut pour passer  l'image suivante.
             tirs[new_tir].spr.nbr_vbl_act = 0;                 // Indique le nombre de VBL comptes actuellement.
@@ -427,7 +428,7 @@ void Fill_Struct_Player_One()
   //vj[J1].type_vaisseau = V5J ; // Donne le type de vaisseau du joueur.
   vj[J1].score = 0L;                                           // Initialise le score du joueur.
   vj[J1].cad_tir = 50 - (vj[J1].type_vaisseau * 5 + 5);        // Nombre de VBLs ncessaires avant que le vaisseau puisse  noubeau tirer.
-  vj[J1].freeze_tmps = 0;                                      // Nombre de VBLs pendant lequel, le vaisseau est fig.
+	//vj[J1].freeze_tmps = 0;
   vj[J1].vit_dep_vaisseau = 2;                                 // Indique l'option vitesse actuellement slectionn par le vaisseau.
   vj[J1].power_avant = 1;                                      // Indique l'option tir avant actuellement slectionn par le vaisseau.
   vj[J1].power_gauche = 0;                                     // Indique l'option tir gauche actuellement slectionn par le vaisseau.
@@ -442,8 +443,8 @@ void Fill_Struct_Player_One()
   vj[J1].spr.trajectoire = 1;                                  // Indique que la trajectoire du sprite est recalcule  chaque VBL.
   vj[J1].spr.pow_of_dest = (short)(vj[J1].type_vaisseau * 20 + 20);     // Indique la puissance de destruction du sprite.
   vj[J1].spr.etat_dommages = vj[J1].spr.pow_of_dest;           // Indique l'tat de domages du sprite.
-  vj[J1].spr.pilote = 1;                                       // Indique par qui est dirig le sprite.
-  vj[J1].spr.mode_commande = 0;                                // Indique le moyen par lequel on fait dplacer le sprite.
+  //vj[J1].spr.pilote = 1;                                       // Indique par qui est dirig le sprite.
+  //vj[J1].spr.mode_commande = 0;                                // Indique le moyen par lequel on fait dplacer le sprite.
   vj[J1].spr.nbr_img = NBR_MAX_IMG_VAIS_J;                     // Indique le nombre d'images composant le sprite.
   vj[J1].spr.img_act = 2;                                      // Indique l'image actuelle.
   vj[J1].spr.nbr_tot_vbl = 10;                                 // Indique le nombre de VBL qu'il faut pour passer  l'image suivante.
