@@ -1,9 +1,9 @@
 //*****************************************************************************
-// copyright (c) 1998-2003 TLK Games all rights reserved
+// copyright (c) 1998-2005 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "xwindow.cpp"
 // created      : 1999-08-17
-// updates      : 2003-07-01
+// updates      : 2005-01-08
 //-----------------------------------------------------------------------------
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -75,6 +75,7 @@ int                     iCouleurBlanche = 0;
 unsigned int            iLargeurEcranTotal = 0;                //taille d'une ligne du buffer 'ecran_ram'
 int                     vmode = 1;                             //0=resolution de 320x200 / 1=640*400 / 2=640*400 (double pixels)
 
+
 //..............................................  ................................
 int                     fullscreen = 0;                        //1=marche en plein ecran
 int                     iDGAFlags;
@@ -93,7 +94,6 @@ unsigned int            iAffiche = 0;                          //1=update displa
 //..............................................................................
 extern bool             bar_nrj_player;
 extern char            *ecran_ram;                             //adresse du buffer de 512x440 (XImage)
-extern unsigned int     iVerbeux;                              //1=affiche les arguments
 extern short            touch[500];                            //tableau des flags de toutes les touches clavier
 extern int              quit_game;                             //1=demande a quitter le jeu
 
@@ -119,6 +119,7 @@ extern unsigned char   *image1;                                //pointer to the
 extern unsigned int     iBarreNrjJoueurXWindow;                //1=update player's enerny bar-line 
 extern unsigned int     iBarreNrjGardienXWindow;               //1=update bigboss's energy bar-line
 extern unsigned int     iScoreXWindow;                         //1=update player's score points
+extern configfile*	power_conf;
 
 //..............................................................................
 const int               IMASQUE_EVENEMENTS =
@@ -154,7 +155,7 @@ int xw_init()
 
   //..............................................................................
 #ifdef _VERBEUX_
-  if(iVerbeux == 1)
+  if(power_conf->verbose)
     afficheMessage("xwindow/xw_init() : start : xwindow intialize");
 #endif
   if(!vmode)
@@ -245,7 +246,7 @@ int xw_init()
   iLargeurRacine = DisplayWidth(pPowerMangaDisplay, _iEcran);
   iHauteurRacine = DisplayHeight(pPowerMangaDisplay, _iEcran);
 #ifdef _VERBEUX_
-  if(iVerbeux == 1)
+  if(power_conf->verbose)
   {
     printf
       ("depth of screen : %i ; bytes per pixel:%i ; size screen : (%i,%i) ;\n",
@@ -332,7 +333,7 @@ int xw_init()
     XF86DGAGetViewPortSize(pPowerMangaDisplay, _iEcran, &iDGALargeur,
                            &iDGAHauteur);
 #ifdef _VERBEUX_
-    if(iVerbeux > 0)
+    if(power_conf->verbose)
     {
       printf
         ("pDGAmemoire=%X ; iDGAtailleLigne=%i ; iDGAbanksize=%i  ; iDGAtailleMemoire=%i ; iDGALargeur=%i ; iDGAHauteur=%i\n",
@@ -348,7 +349,7 @@ int xw_init()
 
   initialiseCurseurBlanc();
 #ifdef _VERBEUX_
-  if(iVerbeux == 1)
+  if(power_conf->verbose)
     printf
       ("xwindow/xw_init() : end xwindow intialisation fullscreen=%i vmode=%i  iLargeurEcran=%i\n",
        fullscreen, vmode, iLargeurEcran);
@@ -586,7 +587,7 @@ int xw_exec()
        // . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . 
       default:
 #ifdef _VERBEUX_
-        if(iVerbeux > 1)
+        if(power_conf->verbose)
           printf("xwindow.cpp / xw_exec() : evenement type=%i\n",
                  sEvenements.type);
 #endif
@@ -1156,7 +1157,7 @@ int xw_kill()
     XDestroyWindow(pPowerMangaDisplay, pFenetreJeu);
     pFenetreJeu = 0;
 #ifdef _VERBEUX_
-    if(iVerbeux > 0)
+    if(power_conf->verbose)
       afficheMessage("XDestroyWindow");
 #endif
   }
@@ -1165,7 +1166,7 @@ int xw_kill()
     XFreeGC(pPowerMangaDisplay, pContexteGraphique);
     pContexteGraphique = 0;
 #ifdef _VERBEUX_
-    if(iVerbeux > 0)
+    if(power_conf->verbose)
       afficheMessage("XFreeGC");
 #endif
   }
@@ -1174,7 +1175,7 @@ int xw_kill()
     XCloseDisplay(pPowerMangaDisplay);
     pPowerMangaDisplay = 0;
 #ifdef _VERBEUX_
-    if(iVerbeux > 0)
+    if(power_conf->verbose)
       afficheMessage("XCloseDisplay");
 #endif
   }
@@ -1329,7 +1330,7 @@ XImage                 *creeXImage(unsigned int _iLarge, unsigned int _iHaute)
   pListeXImage[_iXimageLibre] = _pXImage;
   iNombreXImage++;
 #ifdef _VERBEUX_
-  if(iVerbeux > 0)
+  if(power_conf->verbose)
     afficheMessage("xwindow.cpp/creeXImage() : XShmCreateImage");
 #endif
   return _pXImage;
@@ -1379,7 +1380,7 @@ XImage                 *creeXImage(unsigned int _iLarge, unsigned int _iHaute)
   pListeXImage[_iXimageLibre] = _pXImage;
   iNombreXImage++;
 #ifdef _VERBEUX_
-  if(iVerbeux > 0)
+  if(power_conf->verbose)
     afficheMessage("xwindow.cpp/creeXImage() : XCreateImage\n");
 #endif
   return _pXImage;
@@ -1405,7 +1406,7 @@ void libereXImage(XImage * _pXImage)
       pListeXImage[_iIndex] = 0;
       iNombreXImage--;
 #ifdef _VERBEUX_
-      if(iVerbeux > 0)
+      if(power_conf->verbose)
         afficheMessage
           ("xwindow.cpp/libereXImage() : XShmDetach and XDestroyImage");
 #endif
@@ -1427,7 +1428,7 @@ void libereXImage(XImage * _pXImage)
       pListeXImage[_iIndex] = 0;
       iNombreXImage--;
 #ifdef _VERBEUX_
-      if(iVerbeux > 0)
+      if(power_conf->verbose)
         afficheMessage("xwindow.cpp/libereXImage() : XDestroyImage");
 #endif
       break;
@@ -1459,7 +1460,7 @@ void libereXImages()
       pListeXImage[_iIndex] = 0;
       iNombreXImage--;
 #ifdef _VERBEUX_
-      if(iVerbeux > 0)
+      if(power_conf->verbose)
         afficheMessage("xwindow.cpp/libereXImages() : XDestroyImage");
 #endif
     }
@@ -1479,7 +1480,7 @@ void libereXImages()
       pListeXImage[_iIndex] = 0;
       iNombreXImage--;
 #ifdef _VERBEUX_
-      if(iVerbeux > 0)
+      if(power_conf->verbose)
         afficheMessage
           ("xwindow.cpp/libereXImages() : XShmDetach and XDestroyImage");
 #endif
